<?php

namespace HCM\Geral\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;
use HCM\Util\Repositories;
use HCM\Util\Messages;

class BancoAgenciaController extends Crud {

    protected $BancoAgenciaService;
    protected $dataSourceName = 'banco';
    protected $dataSourceName1 = 'agencia_get';
    
    protected $parameterBagColumns = array('P_NRORG', 'P_NRORG_PADRAO');
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters, \HCM\Geral\Services\BancoAgenciaService $BancoAgenciaService){
        $this->parameterBag = $parameterBag;
        $this->hcmParameters = $hcmParameters;
        $this->bancoAgenciaService = $BancoAgenciaService;
        parent::__construct($dataSourceManager);
    }

    public function getBanco(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getAgencia(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName1);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function setBanco(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (array_key_exists('CDBANCO', $row)) {
                    if ($row['CDBANCO'] === '') {
                       $row['CDBANCO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'BANCO', 1, 12, true); 
                    }
                } else {
                    $row['CDBANCO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'BANCO', 1, 12, true); 
                }
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function setAgencia(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $this->dataSourceName = "agencia";
            foreach ($request->getDataSet()->getRows() as &$row) {
                if(!array_key_exists('CDPAIS', $row)){
                    $row['CDPAIS'] = null;
                }
                if(!array_key_exists('SGESTADO', $row)){
                    $row['SGESTADO'] = null;
                }
                if(!array_key_exists('CDMUNICIPIO', $row)){
                    $row['CDMUNICIPIO'] = null;
                }
                if(!array_key_exists('DTULTATUAGEN', $row)){
                    $row['DTULTATUAGEN'] = $row['DTULTATU'];
                }
                if($row['__is_new'] == true){
                    $retorno = $this->bancoAgenciaService->findAgencia($row['CDBANCO'], $row['CDAGENCIA'], $row['NRORG']);
                }else{
                    $retorno = false;
                }
                if($retorno == false ){
                    parent::save($request, $response);
                    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("Registro salvo com sucesso!"));
                }else{
                    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("Agência já cadastrada!"));
                }
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteBanco(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $dataset = $request->getDataSet()->getRows();
            $dataset = $dataset[0];
            $this->bancoAgenciaService->deleteBanco($dataset);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('delete', array(true)));
        } catch(\Exception $e) {
            if ($e->getCode() === 10) {
                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            }  
            else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
 	        }
        }
    }
    
    public function deleteAgencia(DTO\Request\DataSet $request, DTO\Response $response){
        $this->dataSourceName = "agencia";
        parent::delete($request, $response);
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
} 