<?php
namespace HCM\Geral\Repository\Esocial;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;

class S1210Repository {

    protected  $connection;

    public function __construct(Connection $connection, EntityManager $entityManager, HCMParameters $hcmParameters) {
        $this->connection = $connection;
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
    }

    /*-------------------------- Métodos para retornar os dados do eventos -----------------------------------------------*/
    
    /**
     * @param $nrestruturam
     * @param $nrchave
     * @param $nrtabela
     * @param $dtocorrencia
     * @param $nrtpambiente
     * @return array    Associative array
     */
    public function getDadosS1210($nrestruturam, $nrchave, $nrtabela, $dtocorrencia, $nrtpambiente) {
        /*Busca os dados referentes ao empregador*/
        $sql = <<<SQL
/*getDadosS1210 - Dados do Empregador*/
SELECT /*ideEmpregador*/
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') TPINSC,
       CASE WHEN PAR.CDTIPOINSCRICAO = 'CPF' OR EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END NRINSC,
       PAR.NRINSCRICAOPARC NRINSCRICAOPARC,
       DECODE(:P_NRTPAMBIENTE, 1, DECODE(EMH.IDOPTSIMPLES, 'S', :P_INIVALIDADEAMBNS, :P_INIVALIDADEAMBP), 2, :P_INIVALIDADEAMBPR) INIVALIDADEAMB
  FROM ESTRUTURAM EMM
  LEFT JOIN ESTRUTURAH EMH ON EMH.NRORG = :P_NRORG
                          AND EMH.NRESTRUTURAM = :P_NRESTRUTURAM
                          AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                     WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                       AND ESTRUTURAH.NRESTRUTURAM = EMH.NRESTRUTURAM
                                                       AND ESTRUTURAH.NRORG = EMH.NRORG)
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
 WHERE EMM.NRORG = :P_NRORG
   AND EMM.NRESTRUTURAM = :P_NRESTRUTURAM
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRESTRUTURAM" => $nrestruturam,
            "P_NRTPAMBIENTE" => $nrtpambiente,
            "P_INIVALIDADEAMBPR" => $this->hcmParameters->getEsoIniValidPeriodProdRest(),
            "P_INIVALIDADEAMBP" => $this->hcmParameters->getEsoIniValidPeriodProducao(),
            "P_INIVALIDADEAMBNS" => $this->hcmParameters->getEsoIniValidPeriodNacioSimples(),
        );
        $empregador = $this->connection->fetchAssoc($sql, $params);
        
        $sql = <<<SQL
/*getDadosS1210 - Dados da Pessoa*/
/*Pessoas sem transferência*/
SELECT PE.NRORG, PE.NRPESSOA, PE.NRPARCNEGOCIO, PH.NRCPFPESSOA,
       '_'||(LISTAGG(VM.NRVINCULOM, '_') WITHIN GROUP (ORDER BY VM.NRVINCULOM))||'_' NRVINCULOMLIST
  FROM GPE_VINCULOM VM
  /*Dados do Empregado - Vínculo*/
  JOIN GPE_VINCULOH VH
    ON VH.NRVINCULOM = VM.NRVINCULOM
   AND VH.NRORG      = VM.NRORG
   AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                             WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_VINCULOH.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                               AND GPE_VINCULOH.NRVINCULOM = VM.NRVINCULOM
                               AND GPE_VINCULOH.NRORG = VM.NRORG)
  /*Dados do Empregado - Pessoa*/                               
  JOIN GPE_PESSOA PE
    ON PE.NRPESSOA = VM.NRPESSOA
   AND PE.NRORG    = VM.NRORG
  JOIN GPE_PESSOAH PH
    ON PH.NRPESSOA = PE.NRPESSOA
   AND PH.NRORG    = PE.NRORG
   AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                             WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_PESSOAH.NRPESSOA = PE.NRPESSOA
                               AND GPE_PESSOAH.NRORG = PE.NRORG)
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRPESSOA = :P_NRCHAVE
 GROUP BY PE.NRORG, PE.NRPESSOA, PE.NRPARCNEGOCIO, PH.NRCPFPESSOA
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRCHAVE" => $nrchave,
        );
        $dadosPessoa = $this->connection->fetchAssoc($sql, $params);
        
        /*Busca os dados do evento*/
        $sql = <<<SQL
/*getDadosS1210*/
SELECT DISTINCT
       /*ideEvento*/
       1 as indApuracao,
       TO_CHAR(IT.DTOCORRENCIA, 'YYYY-MM') as perApur,
       /*ideEmpregador*/
       :P_TPINSC TPINSC,
       :P_NRINSC NRINSC,
       /*ideBenef*/
       REPLACE(REPLACE(:P_NRCPFPESSOA, '.'), '-') AS cpfBenef,  
       /*ideBenef*/
       (SELECT SUM(I.VREVENTOFOLHA) FROM FPA_ITECALCFOLHA I
         WHERE I.NRORG = CF.NRORG
           AND I.NRCALCULOFOLHA = CF.NRCALCULOFOLHA
           AND I.NRVINCULOM = VM.NRVINCULOM
           AND I.NREVENTOM = 1290 /*ASSOC_DEDUCAO_DEPENDENTE*/) vrDedDep,
       /*infoPgto getDadosS1210infoPgto*/
       :P_NRPESSOA AS NRPESSOA, :P_NRPARCNEGOCIO AS NRPARCNEGOCIO, :P_NRVINCULOMLIST AS NRVINCULOMLIST,
       CASE
         WHEN (SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8) AND EHN.DTINIMOVIMENT IS NULL AND EHS.DTINIMOVIMENT IS NULL) THEN 'N'
         WHEN (SUBSTR(EHS.CDCNPJESTRUT,1,8) <> SUBSTR(EH.CDCNPJESTRUT,1,8) AND SUBSTR(EHS.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)) THEN 'S'
         WHEN (SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)) THEN 'E'
       END AS IDTRANSFERENCIA,
       EHN.CDCNPJESTRUT AS CDCNPJESTRUTENTR, EHN.DTINIMOVIMENT AS DTINIMOVIMENTENTR, EHN.DTFIMMOVIMENT AS DTFIMMOVIMENTENTR,
       EHS.CDCNPJESTRUT AS CDCNPJESTRUTSAID, EHS.DTINIMOVIMENT AS DTINIMOVIMENTSAID, EHS.DTFIMMOVIMENT AS DTFIMMOVIMENTSAID,
       :P_NRINSCRICAOPARC AS NRINSCRICAOPARC, :P_NRTABELA AS NRTABELA, SUBSTR(:P_DTOCORRENCIA,0,10) AS DTOCORRENCIA, :P_NRTPAMBIENTE AS NRTPAMBIENTE, :P_INIVALIDADEAMB INIVALIDADEAMB
  /*Dados do Empregado - Vínculo*/
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                                                WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND GPE_VINCULOH.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND GPE_VINCULOH.NRVINCULOM = VH.NRVINCULOM
                                                  AND GPE_VINCULOH.NRORG = VH.NRORG)
  /*Estrutura Legal*/
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Movimentação de entrada*/
  LEFT JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT, MO.DTINIMOVIMENT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 8
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHN ON EHN.NRORG = VH.NRORG
                                                                                                   AND EHN.NRVINCULOM = VH.NRVINCULOM
                                                                                                   AND SUBSTR(EHN.CDCNPJESTRUT,1,8) = SUBSTR(EH.CDCNPJESTRUT,1,8)
  /*Movimentacao de saida*/
  LEFT JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT, MO.DTINIMOVIMENT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 9
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHS ON EHS.NRORG = VH.NRORG
                                                                                                   AND EHS.NRVINCULOM = VH.NRVINCULOM
  /*Calculo*/
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = VH.NRORG
                          AND IT.NRVINCULOM = VH.NRVINCULOM
                          AND IT.NREVENTOM IN (3030,3050)
                          AND TRUNC(IT.DTOCORRENCIA,'MONTH') = :P_DTOCORRENCIA
  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = IT.NRORG
                          AND CF.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
                          AND CF.NRTIPOMOVIMENT IN (1,2,4,10,19)
                          AND CF.NRTPMODALIDCAL = 1
                          AND ((1=1) OR
                               (CF.DTOCORRENCIA = TRUNC(EHS.DTFIMMOVIMENT,'MONTH')) OR
                               (EHN.DTINIMOVIMENT IS NOT NULL AND CF.DTOCORRENCIA >= :P_DTOCORRENCIA))
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRPESSOA = :P_NRPESSOA
   AND (
        (SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8) AND EHN.DTINIMOVIMENT IS NULL AND EHS.DTINIMOVIMENT IS NULL) OR
        (SUBSTR(EHS.CDCNPJESTRUT,1,8) <> SUBSTR(EH.CDCNPJESTRUT,1,8) AND SUBSTR(EHS.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)) OR
        (SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8))
       )
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRESTRUTURAM" => $nrestruturam,
            "P_NRTPAMBIENTE" => $nrtpambiente,
            "P_NRTABELA" => $nrtabela,
            "P_DTOCORRENCIA" => $dtocorrencia,
            "P_TPINSC" => $empregador['TPINSC'],
            "P_NRINSC" => $empregador['NRINSC'],
            "P_NRINSCRICAOPARC" => $empregador['NRINSCRICAOPARC'],
            "P_INIVALIDADEAMB" => $empregador['INIVALIDADEAMB'],
            "P_NRPESSOA" => $dadosPessoa['NRPESSOA'],
            "P_NRPARCNEGOCIO" => $dadosPessoa['NRPARCNEGOCIO'],
            "P_NRCPFPESSOA" => $dadosPessoa['NRCPFPESSOA'],
            "P_NRVINCULOMLIST" => $dadosPessoa['NRVINCULOMLIST'],
        );
        return $this->connection->fetchAssoc($sql, $params);
    }
    
    public function getDadosS1210infoPgto_semTransf($parametros) {
        $sql = <<<SQL
SELECT '_'||LISTAGG(NRCALCULOFOLHA, '_') WITHIN GROUP (ORDER BY NRCALCULOFOLHA)||'_' NRCALCULOFOLHALIST
  FROM (SELECT DISTINCT ITC.NRCALCULOFOLHA
          FROM FPA_ITECALCFOLHA ITC
          JOIN FPA_EVENTOH EH ON EH.NREVENTOM = ITC.NREVENTOM
                             AND (EH.NRORG = ITC.NRORG OR EH.NRORG = :P_NRORG_PADRAO)
                             AND EH.DTMESCOMPETENC = (SELECT MAX(EHH.DTMESCOMPETENC)
                                                        FROM FPA_EVENTOH EHH
                                                       WHERE EHH.NREVENTOM = EH.NREVENTOM
                                                         AND EHH.NRORG = EH.NRORG
                                                         AND EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
          JOIN NATUREZARUBRICA NR ON NR.NRNATURUBR = EH.NRNATURUBR
          WHERE ITC.NRORG = :P_NRORG
            AND ITC.NRCALCULOFOLHA IN (SELECT CF.NRCALCULOFOLHA FROM FPA_CALCULOFOLHA CF
                                        WHERE CF.NRORG = :P_NRORG
                                          AND CF.DTOCORRENCIA BETWEEN ADD_MONTHS(TO_DATE(:P_DTMESCOMPETENC),-3) AND :P_DTMESCOMPETENC
                                          AND CF.NRTIPOMOVIMENT IN (1,2,4,10,19)
                                          AND CF.NRTPMODALIDCAL = 1)
           AND INSTR(:P_NRVINCULOMLIST, '_'||ITC.NRVINCULOM||'_') > 0
           AND ITC.DTOCORRENCIA BETWEEN ADD_MONTHS(TO_DATE(:P_DTMESCOMPETENC),-3) AND :P_DTMESCOMPETENC
           AND ITC.VREVENTOFOLHA > 0
           AND ((ITC.IDEVENDEMONCALC = 'N' AND EH.IDEVENTODEMONST = 'N') OR (EH.IDEVENTODEMONST = 'S')))
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_NRORG_PADRAO" => $this->hcmParameters->getNrorgPadrao(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_DTFIMMOVIMENTSAID" => $parametros['DTFIMMOVIMENTSAID'],
            "P_NRVINCULOMLIST" => $parametros['NRVINCULOMLIST'],
        );
        $calculos = $this->connection->fetchAssoc($sql, $params);
        
        $sql = <<<SQL
/*getDadosS1210infoPgto*/
/*Pessoas sem transferência*/
SELECT DISTINCT TO_CHAR(IT.DTOCORRENCIA, 'YYYY-MM-DD') dtPgto,
       DECODE(IT.NREVENTOM, 3050, 
         CASE WHEN VM.DTRESCISAOVINC < :P_INIVALIDADEAMB THEN '9'
              WHEN VM.DTRESCISAOVINC <= RESC.DTOCORRENCIA THEN '1' 
              ELSE DECODE(VM.NRTIPOVINCULOM,1,'2','3') 
         END,
         CASE WHEN CF.DTOCORRENCIA < TRUNC(TO_DATE(:P_INIVALIDADEAMB),'MM') THEN '9' 
              WHEN (CALCULORESC.NRCALCULOFOLHA IS NOT NULL OR TRUNC(TO_DATE(VM.DTRESCISAOVINC),'MONTH') = TO_DATE(CF.DTOCORRENCIA))  AND CF.NRTIPOMOVIMENT <> 2 AND ENVIODT.NRENVIO IS NULL THEN DECODE(VM.NRTIPOVINCULOM,1,'2','3')
              ELSE DECODE(CF.NRTIPOMOVIMENT,2,'7','1') 
         END
       ) tpPgto,
       DECODE(NVL(EP.CDPAIS,'0055'),'0055','S','N') indResBr,
       /*detPgtoFl getDadosS1210detPgtoFl*/
       /*detPgtoBenPr getDadosS1210detPgtoBenPr*/
       /*detPgtoFer getDadosS1210detPgtoFer*/
       /*detPgtoAnt getDadosS1210detPgtoAnt*/
       VM.NRORG, VM.NRPESSOA, IT.DTOCORRENCIA, DECODE(VM.DTRESCISAOVINC,NULL,NULL,CF.DTOCORRENCIA) DTOCORRECALC,
       :P_NRTABELA NRTABELA, :P_NRINSCRICAOPARC NRINSCRICAOPARC, :P_NRTPAMBIENTE AS NRTPAMBIENTE, :P_INIVALIDADEAMB INIVALIDADEAMB
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = VH.NRORG
                          AND CF.DTOCORRENCIA BETWEEN ADD_MONTHS(TO_DATE(:P_DTMESCOMPETENC),-3) AND :P_DTMESCOMPETENC
						  AND INSTR(:P_NRCALCULOFOLHALIST, '_'||CF.NRCALCULOFOLHA||'_') > 0
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = CF.NRORG
                          AND IT.NRCALCULOFOLHA = CF.NRCALCULOFOLHA
                          AND IT.NRVINCULOM = VH.NRVINCULOM
                          AND IT.NREVENTOM IN (3030,3050)
                          AND TRUNC(IT.DTOCORRENCIA,'MONTH') = :P_DTOCORRENCIA
  /*Verifica se o 13 foi enviado no S-1200 ou no S-2299*/
  LEFT JOIN (SELECT EC.*
               FROM ESO_ENVIOCADASTROS EC
               LEFT JOIN ESTRUTURAH ESH ON ESH.NRORG = EC.NRORG
                                  AND ESH.NRESTRUTURAM = EC.NRESTRUTURAM
                                  AND SUBSTR(ESH.CDCNPJESTRUT, 1, 8) =  SUBSTR(:P_NRINSCRICAOPARC, 1,8)
                                  AND ESH.DTMESCOMPETENC = (SELECT MAX(ESHH.DTMESCOMPETENC)
                                                              FROM ESTRUTURAH ESHH
                                                             WHERE ESHH.NRORG = ESH.NRORG
                                                               AND ESHH.NRESTRUTURAM = ESH.NRESTRUTURAM
                                                               AND ESHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE EC.IDSTATUS IN ('C', 'A')
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
                AND EC.NRTABELA = 4
                AND TRUNC(TO_DATE(EC.DTMESCOMPETENC), 'YEAR') = TRUNC(TO_DATE(:P_DTMESCOMPETENC), 'YEAR')
                AND EC.NRENVIOEXCL IS NULL
                AND ESH.NRESTRUTURAM IS NOT NULL
                AND EC.IDATIVO = 'S'
                AND EC.NREVENTO IN (SELECT SE.NREVENTO
                                      FROM ESO_EVENTO SE
                                     WHERE SE.NMEVENTO = 'S-1200')) ENVIODT ON ENVIODT.NRCHAVE = VM.NRPESSOA 
                                                                           AND ENVIODT.NRORG = VM.NRORG
                                                                           AND ENVIODT.NRTABELA  = CF.NRTIPOMOVIMENT
                                                                           AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12'
                                                                           AND CF.NROCORRECAL = 1
  /*Busca rescisão anterior em caso de complementar*/
  LEFT JOIN (SELECT /*+ INDEX (ITC FPA_ITECALCFOLHA_UK1)*/ ITC.NRORG, ITC.NRVINCULOM, MAX(ITC.DTOCORRENCIA) DTOCORRENCIA, CFC.DTOCORRENCIA DTOCORRENCIACALC
               FROM FPA_CALCULOFOLHA CFC 
               JOIN FPA_ITECALCFOLHA ITC ON CFC.NRORG = ITC.NRORG
   			   						    AND CFC.DTOCORRENCIA BETWEEN ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC), 'YEAR'),-12) AND :P_DTMESCOMPETENC
										AND CFC.NRCALCULOFOLHA = ITC.NRCALCULOFOLHA
                                        AND CFC.NRTIPOMOVIMENT = 1
                                        AND CFC.NRTPMODALIDCAL = 1
              WHERE ITC.NRORG = :P_NRORG
                AND ITC.NREVENTOM = 3050
                AND TRUNC(CFC.DTOCORRENCIA,'MONTH') < :P_DTOCORRENCIA
              GROUP BY ITC.NRORG, ITC.NRVINCULOM, CFC.DTOCORRENCIA) RESC ON RESC.NRORG = IT.NRORG
                                                                        AND RESC.NRVINCULOM = IT.NRVINCULOM
                                                                        AND RESC.DTOCORRENCIACALC < CF.DTOCORRENCIA
   /*Busca cálculo para verificar se é um adiantamento com rescisão*/
   LEFT JOIN (SELECT /*+ INDEX (ITC FPA_ITECALCFOLHA_UK1)*/ ITC.NRORG, ITC.NRVINCULOM, MAX(ITC.DTOCORRENCIA) DTOCORRENCIA, CFC.NRCALCULOFOLHA
               FROM FPA_CALCULOFOLHA CFC
               JOIN FPA_ITECALCFOLHA ITC ON CFC.NRORG = ITC.NRORG
                                        AND CFC.DTOCORRENCIA BETWEEN ADD_MONTHS(TO_DATE(:P_DTMESCOMPETENC),-3) AND :P_DTMESCOMPETENC
                         			    AND CFC.NRCALCULOFOLHA = ITC.NRCALCULOFOLHA
                                        AND CFC.NRTIPOMOVIMENT = 1
                                        AND CFC.NRTPMODALIDCAL = 1
              WHERE ITC.NRORG = :P_NRORG
                AND ITC.NREVENTOM = 3050
              GROUP BY ITC.NRORG, ITC.NRVINCULOM, ITC.DTOCORRENCIA, CFC.NRCALCULOFOLHA) CALCULORESC ON CALCULORESC.NRORG = IT.NRORG
                                                                                                   AND CALCULORESC.NRVINCULOM = IT.NRVINCULOM
                                                                                                   AND TRUNC(CALCULORESC.DTOCORRENCIA,'MONTH') = TRUNC(CF.DTOCORRENCIA,'MONTH')
  LEFT JOIN ENDERECOPARC EP ON EP.NRORG = VH.NRORG
                           AND EP.NRPARCNEGOCIO = :P_NRPARCNEGOCIO
                           AND EP.CDTIPOENDERECO = 'PRINCIPAL'
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRPESSOA = :P_NRPESSOA
   AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
   AND (((VM.DTRESCISAOVINC IS NULL OR VM.DTRESCISAOVINC >= :P_DTMESCOMPETENC) AND IT.NREVENTOM = 3030) OR (VM.DTRESCISAOVINC <= LAST_DAY(:P_DTMESCOMPETENC) AND IT.NREVENTOM = 3050))
   AND SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_NRORG_PADRAO" => $this->hcmParameters->getNrorgPadrao(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_INIVALIDADEAMB" => $parametros['INIVALIDADEAMB'],
            "P_NRPESSOA" => $parametros['NRPESSOA'],
            "P_NRPARCNEGOCIO" => $parametros['NRPARCNEGOCIO'],
            "P_NRINSCRICAOPARC" => $parametros['NRINSCRICAOPARC'],
            "P_NRTABELA" => $parametros['NRTABELA'],
            "P_DTOCORRENCIA" => $parametros['DTOCORRENCIA'],
            "P_NRTPAMBIENTE" => $parametros['NRTPAMBIENTE'],
            "P_DTFIMMOVIMENTSAID" => $parametros['DTFIMMOVIMENTSAID'],
            "P_NRCALCULOFOLHALIST" => $calculos['NRCALCULOFOLHALIST'],
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS1210infoPgto_transfSaid($parametros) {
        $sql = <<<SQL
SELECT '_'||LISTAGG(NRCALCULOFOLHA, '_') WITHIN GROUP (ORDER BY NRCALCULOFOLHA)||'_' NRCALCULOFOLHALIST
  FROM (SELECT DISTINCT ITC.NRCALCULOFOLHA
          FROM FPA_ITECALCFOLHA ITC
          JOIN FPA_EVENTOH EH ON EH.NREVENTOM = ITC.NREVENTOM
                             AND (EH.NRORG = ITC.NRORG OR EH.NRORG = :P_NRORG_PADRAO)
                             AND EH.DTMESCOMPETENC = (SELECT MAX(EHH.DTMESCOMPETENC)
                                                        FROM FPA_EVENTOH EHH
                                                       WHERE EHH.NREVENTOM = EH.NREVENTOM
                                                         AND EHH.NRORG = EH.NRORG
                                                         AND EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
          JOIN NATUREZARUBRICA NR ON NR.NRNATURUBR = EH.NRNATURUBR
          WHERE ITC.NRORG = :P_NRORG
            AND ITC.NRCALCULOFOLHA IN (SELECT CF.NRCALCULOFOLHA FROM FPA_CALCULOFOLHA CF
                                        WHERE CF.NRORG = :P_NRORG
                                          AND CF.DTOCORRENCIA BETWEEN ADD_MONTHS(TO_DATE(:P_DTMESCOMPETENC),-3) AND :P_DTMESCOMPETENC
                                          AND CF.NRTIPOMOVIMENT IN (1,2,4,10,19)
                                          AND CF.NRTPMODALIDCAL = 1
                                          AND CF.DTOCORRENCIA = TRUNC(TO_DATE(:P_DTFIMMOVIMENTSAID),'MONTH'))
           AND INSTR(:P_NRVINCULOMLIST, '_'||ITC.NRVINCULOM||'_') > 0
           AND ITC.DTOCORRENCIA BETWEEN ADD_MONTHS(TO_DATE(:P_DTMESCOMPETENC),-3) AND :P_DTMESCOMPETENC
           AND ITC.VREVENTOFOLHA > 0
           AND ((ITC.IDEVENDEMONCALC = 'N' AND EH.IDEVENTODEMONST = 'N') OR (EH.IDEVENTODEMONST = 'S')))
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_NRORG_PADRAO" => $this->hcmParameters->getNrorgPadrao(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_DTFIMMOVIMENTSAID" => $parametros['DTFIMMOVIMENTSAID'],
            "P_NRVINCULOMLIST" => $parametros['NRVINCULOMLIST'],
            "P_DTFIMMOVIMENTSAID" => $parametros['DTFIMMOVIMENTSAID'],
            "P_NRCALCULOFOLHALIST" => $calculos['NRCALCULOFOLHALIST'],
        );
        $calculos = $this->connection->fetchAssoc($sql, $params);
        
        $sql = <<<SQL
/*getDadosS1210infoPgto*/
/*Pessoas com tranferência de saída na competência*/
SELECT DISTINCT TO_CHAR(IT.DTOCORRENCIA, 'YYYY-MM-DD') dtPgto,
       DECODE(IT.NREVENTOM, 3050, 
         CASE WHEN VM.DTRESCISAOVINC < :P_INIVALIDADEAMB THEN '9' 
              WHEN VM.DTRESCISAOVINC <= RESC.DTOCORRENCIA THEN '1' 
              ELSE DECODE(VM.NRTIPOVINCULOM,1,'2','3') 
         END, 
         CASE WHEN CF.DTOCORRENCIA < TRUNC(TO_DATE(:P_INIVALIDADEAMB),'MM') THEN '9' 
              WHEN (CALCULORESC.NRCALCULOFOLHA IS NOT NULL OR TRUNC(TO_DATE(VM.DTRESCISAOVINC),'MONTH') = TO_DATE(CF.DTOCORRENCIA))  AND CF.NRTIPOMOVIMENT <> 2 AND ENVIODT.NRENVIO IS NULL THEN DECODE(VM.NRTIPOVINCULOM,1,'2','3') 
              ELSE DECODE(CF.NRTIPOMOVIMENT,2,'7','1') 
         END
       ) tpPgto,
       DECODE(NVL(EP.CDPAIS,'0055'),'0055','S','N') indResBr,
       /*detPgtoFl getDadosS1210detPgtoFl*/
       /*detPgtoBenPr getDadosS1210detPgtoBenPr*/
       /*detPgtoFer getDadosS1210detPgtoFer*/
       /*detPgtoAnt getDadosS1210detPgtoAnt*/
       VM.NRORG, VM.NRPESSOA, IT.DTOCORRENCIA, DECODE(VM.DTRESCISAOVINC,NULL,NULL,CF.DTOCORRENCIA) DTOCORRECALC,
       :P_NRTABELA NRTABELA, :P_NRINSCRICAOPARC NRINSCRICAOPARC, :P_NRTPAMBIENTE AS NRTPAMBIENTE, :P_INIVALIDADEAMB INIVALIDADEAMB
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = VH.NRORG
                          AND CF.DTOCORRENCIA BETWEEN ADD_MONTHS(TO_DATE(:P_DTMESCOMPETENC),-3) AND :P_DTMESCOMPETENC
						  AND INSTR(:P_NRCALCULOFOLHALIST, '_'||CF.NRCALCULOFOLHA||'_') > 0
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = CF.NRORG
                          AND CF.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
                          AND IT.NRVINCULOM = VH.NRVINCULOM
                          AND IT.NREVENTOM IN (3030,3050)
                          AND TRUNC(IT.DTOCORRENCIA,'MONTH') = :P_DTOCORRENCIA
  /*Verifica se o 13 foi enviado no S-1200 ou no S-2299*/
  LEFT JOIN (SELECT EC.*
               FROM ESO_ENVIOCADASTROS EC
               LEFT JOIN ESTRUTURAH ESH ON ESH.NRORG = EC.NRORG
                                  AND ESH.NRESTRUTURAM = EC.NRESTRUTURAM
                                  AND SUBSTR(ESH.CDCNPJESTRUT, 1, 8) =  SUBSTR(:P_NRINSCRICAOPARC, 1,8)
                                  AND ESH.DTMESCOMPETENC = (SELECT MAX(ESHH.DTMESCOMPETENC)
                                                              FROM ESTRUTURAH ESHH
                                                             WHERE ESHH.NRORG = ESH.NRORG
                                                               AND ESHH.NRESTRUTURAM = ESH.NRESTRUTURAM
                                                               AND ESHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE EC.IDSTATUS IN ('C', 'A')
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
                AND EC.NRTABELA = 4
                AND TRUNC(TO_DATE(EC.DTMESCOMPETENC), 'YEAR') = TRUNC(TO_DATE(:P_DTMESCOMPETENC), 'YEAR')
                AND EC.NRENVIOEXCL IS NULL
                AND ESH.NRESTRUTURAM IS NOT NULL
                AND EC.IDATIVO = 'S'
                AND EC.NREVENTO IN (SELECT SE.NREVENTO
                                      FROM ESO_EVENTO SE
                                     WHERE SE.NMEVENTO = 'S-1200')) ENVIODT ON ENVIODT.NRCHAVE = VM.NRPESSOA 
                                                                           AND ENVIODT.NRORG = VM.NRORG
                                                                           AND ENVIODT.NRTABELA  = CF.NRTIPOMOVIMENT
                                                                           AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12'
                                                                           AND CF.NROCORRECAL = 1                     
  /*Busca rescisão anterior em caso de complementar*/
  LEFT JOIN (SELECT /*+ INDEX (ITC FPA_ITECALCFOLHA_UK1)*/ ITC.NRORG, ITC.NRVINCULOM, MAX(ITC.DTOCORRENCIA) DTOCORRENCIA, CFC.DTOCORRENCIA DTOCORRENCIACALC
               FROM FPA_ITECALCFOLHA ITC
               JOIN FPA_CALCULOFOLHA CFC ON CFC.NRORG = ITC.NRORG
   			   						    AND CFC.DTOCORRENCIA BETWEEN ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC), 'YEAR'),-12) AND :P_DTMESCOMPETENC
                                        AND CFC.NRCALCULOFOLHA = ITC.NRCALCULOFOLHA
                                        AND CFC.NRTIPOMOVIMENT = 1
                                        AND CFC.NRTPMODALIDCAL = 1
              WHERE ITC.NRORG = :P_NRORG
                AND ITC.NREVENTOM = 3050
                AND TRUNC(ITC.DTOCORRENCIA,'MONTH') < :P_DTOCORRENCIA
              GROUP BY ITC.NRORG, ITC.NRVINCULOM, CFC.DTOCORRENCIA) RESC ON RESC.NRORG = IT.NRORG
                                                                        AND RESC.NRVINCULOM = IT.NRVINCULOM
                                                                        AND RESC.DTOCORRENCIACALC < CF.DTOCORRENCIA
   /*Busca cálculo para verificar se é um adiantamento com rescisão*/
   LEFT JOIN (SELECT /*+ INDEX (ITC FPA_ITECALCFOLHA_UK1)*/ ITC.NRORG, ITC.NRVINCULOM, MAX(ITC.DTOCORRENCIA) DTOCORRENCIA, CFC.NRCALCULOFOLHA
               FROM FPA_ITECALCFOLHA ITC
               JOIN FPA_CALCULOFOLHA CFC ON CFC.NRORG = ITC.NRORG
                                        AND CFC.DTOCORRENCIA BETWEEN ADD_MONTHS(TO_DATE(:P_DTMESCOMPETENC),-3) AND :P_DTMESCOMPETENC
                                        AND CFC.NRCALCULOFOLHA = ITC.NRCALCULOFOLHA
                                        AND CFC.NRTIPOMOVIMENT = 1
                                        AND CFC.NRTPMODALIDCAL = 1
              WHERE ITC.NRORG = :P_NRORG
                AND ITC.NREVENTOM = 3050
              GROUP BY ITC.NRORG, ITC.NRVINCULOM, ITC.DTOCORRENCIA, CFC.NRCALCULOFOLHA) CALCULORESC ON CALCULORESC.NRORG = IT.NRORG
                                                                                                   AND CALCULORESC.NRVINCULOM = IT.NRVINCULOM
                                                                                                   AND TRUNC(CALCULORESC.DTOCORRENCIA,'MONTH') = TRUNC(CF.DTOCORRENCIA,'MONTH')
  LEFT JOIN ENDERECOPARC EP ON EP.NRORG = VM.NRORG
                           AND EP.NRPARCNEGOCIO = :P_NRPARCNEGOCIO
                           AND EP.CDTIPOENDERECO = 'PRINCIPAL'
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRPESSOA = :P_NRPESSOA
   AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
   AND (((VM.DTRESCISAOVINC IS NULL OR VM.DTRESCISAOVINC >= :P_DTMESCOMPETENC) AND IT.NREVENTOM = 3030) OR (VM.DTRESCISAOVINC <= LAST_DAY(:P_DTMESCOMPETENC) AND IT.NREVENTOM = 3050))
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_NRORG_PADRAO" => $this->hcmParameters->getNrorgPadrao(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_INIVALIDADEAMB" => $parametros['INIVALIDADEAMB'],
            "P_NRPESSOA" => $parametros['NRPESSOA'],
            "P_NRPARCNEGOCIO" => $parametros['NRPARCNEGOCIO'],
            "P_NRINSCRICAOPARC" => $parametros['NRINSCRICAOPARC'],
            "P_NRTABELA" => $parametros['NRTABELA'],
            "P_DTOCORRENCIA" => $parametros['DTOCORRENCIA'],
            "P_NRTPAMBIENTE" => $parametros['NRTPAMBIENTE'],
            "P_DTFIMMOVIMENTSAID" => $parametros['DTFIMMOVIMENTSAID'],
            "P_NRCALCULOFOLHALIST" => $calculos['NRCALCULOFOLHALIST'],
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS1210infoPgto_transfEntr($parametros) {
        $sql = <<<SQL
SELECT '_'||LISTAGG(NRCALCULOFOLHA, '_') WITHIN GROUP (ORDER BY NRCALCULOFOLHA)||'_' NRCALCULOFOLHALIST
  FROM (SELECT DISTINCT ITC.NRCALCULOFOLHA
          FROM FPA_ITECALCFOLHA ITC
          JOIN FPA_EVENTOH EH ON EH.NREVENTOM = ITC.NREVENTOM
                             AND (EH.NRORG = ITC.NRORG OR EH.NRORG = :P_NRORG_PADRAO)
                             AND EH.DTMESCOMPETENC = (SELECT MAX(EHH.DTMESCOMPETENC)
                                                        FROM FPA_EVENTOH EHH
                                                       WHERE EHH.NREVENTOM = EH.NREVENTOM
                                                         AND EHH.NRORG = EH.NRORG
                                                         AND EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
          JOIN NATUREZARUBRICA NR ON NR.NRNATURUBR = EH.NRNATURUBR
          WHERE ITC.NRORG = :P_NRORG
            AND ITC.NRCALCULOFOLHA IN (SELECT CF.NRCALCULOFOLHA FROM FPA_CALCULOFOLHA CF
                                        WHERE CF.NRORG = :P_NRORG
                                          AND CF.DTOCORRENCIA BETWEEN ADD_MONTHS(TO_DATE(:P_DTMESCOMPETENC),-3) AND :P_DTMESCOMPETENC
                                          AND CF.NRTIPOMOVIMENT IN (1,2,4,10,19)
                                          AND CF.NRTPMODALIDCAL = 1
                                          AND (:P_DTINIMOVIMENTENTR IS NOT NULL AND CF.DTOCORRENCIA >= :P_DTOCORRENCIA))
           AND INSTR(:P_NRVINCULOMLIST, '_'||ITC.NRVINCULOM||'_') > 0
           AND ITC.DTOCORRENCIA BETWEEN ADD_MONTHS(TO_DATE(:P_DTMESCOMPETENC),-3) AND :P_DTMESCOMPETENC
           AND ITC.VREVENTOFOLHA > 0
           AND ((ITC.IDEVENDEMONCALC = 'N' AND EH.IDEVENTODEMONST = 'N') OR (EH.IDEVENTODEMONST = 'S')))
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_NRORG_PADRAO" => $this->hcmParameters->getNrorgPadrao(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_DTFIMMOVIMENTSAID" => $parametros['DTFIMMOVIMENTSAID'],
            "P_NRVINCULOMLIST" => $parametros['NRVINCULOMLIST'],
            "P_DTFIMMOVIMENTSAID" => $parametros['DTFIMMOVIMENTSAID'],
            "P_NRCALCULOFOLHALIST" => $calculos['NRCALCULOFOLHALIST'],
            "P_DTINIMOVIMENTENTR" => $calculos['DTINIMOVIMENTENTR'],
        );
        $calculos = $this->connection->fetchAssoc($sql, $params);
        
        $sql = <<<SQL
/*getDadosS1210infoPgto*/
/*Pessoas com tranferência de entrada na competência*/
SELECT  distinct TO_CHAR(IT.DTOCORRENCIA, 'YYYY-MM-DD') dtPgto,
       DECODE(IT.NREVENTOM, 3050, CASE WHEN VM.DTRESCISAOVINC < :P_INIVALIDADEAMB THEN '9' WHEN VM.DTRESCISAOVINC <= RESC.DTOCORRENCIA THEN '1' ELSE DECODE(VM.NRTIPOVINCULOM,1,'2','3') END, CASE WHEN CF.DTOCORRENCIA < TRUNC(TO_DATE(:P_INIVALIDADEAMB),'MM') THEN '9' WHEN (CALCULORESC.NRCALCULOFOLHA IS NOT NULL OR TRUNC(TO_DATE(VM.DTRESCISAOVINC),'MONTH') = TO_DATE(CF.DTOCORRENCIA))  AND CF.NRTIPOMOVIMENT <> 2 AND ENVIODT.NRENVIO IS NULL THEN DECODE(VM.NRTIPOVINCULOM,1,'2','3') ELSE DECODE(CF.NRTIPOMOVIMENT,2,'7','1') END) tpPgto,
       DECODE(NVL(EP.CDPAIS,'0055'),'0055','S','N') indResBr,
       /*detPgtoFl getDadosS1210detPgtoFl*/
       /*detPgtoBenPr getDadosS1210detPgtoBenPr*/
       /*detPgtoFer getDadosS1210detPgtoFer*/
       /*detPgtoAnt getDadosS1210detPgtoAnt*/
       VM.NRORG, VM.NRPESSOA, IT.DTOCORRENCIA, :P_NRTABELA NRTABELA, :P_NRINSCRICAOPARC NRINSCRICAOPARC, :P_NRTPAMBIENTE AS NRTPAMBIENTE, :P_INIVALIDADEAMB INIVALIDADEAMB, DECODE(VM.DTRESCISAOVINC,NULL,NULL,CF.DTOCORRENCIA) DTOCORRECALC
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = VH.NRORG
                          AND CF.DTOCORRENCIA BETWEEN ADD_MONTHS(TO_DATE(:P_DTMESCOMPETENC),-3) AND :P_DTMESCOMPETENC
						  AND INSTR(:P_NRCALCULOFOLHALIST, '_'||CF.NRCALCULOFOLHA||'_') > 0
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = CF.NRORG
                          AND CF.NRCALCULOFOLHA = IT.NRCALCULOFOLHA  
                          AND IT.NRVINCULOM = VH.NRVINCULOM
                          AND IT.NREVENTOM IN (3030,3050)
                          AND TRUNC(IT.DTOCORRENCIA,'MONTH') = :P_DTOCORRENCIA

  /*Verifica se o 13 foi enviado no S-1200 ou no S-2299*/
  LEFT JOIN (SELECT EC.*
               FROM ESO_ENVIOCADASTROS EC
               LEFT JOIN ESTRUTURAH ESH ON ESH.NRORG = EC.NRORG
                                  AND ESH.NRESTRUTURAM = EC.NRESTRUTURAM
                                  AND SUBSTR(ESH.CDCNPJESTRUT, 1, 8) =  SUBSTR(:P_NRINSCRICAOPARC, 1,8)
                                  AND ESH.DTMESCOMPETENC = (SELECT MAX(ESHH.DTMESCOMPETENC)
                                                              FROM ESTRUTURAH ESHH
                                                             WHERE ESHH.NRORG = ESH.NRORG
                                                               AND ESHH.NRESTRUTURAM = ESH.NRESTRUTURAM
                                                               AND ESHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE EC.IDSTATUS IN ('C', 'A')
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
                AND EC.NRTABELA = 4
                AND TRUNC(TO_DATE(EC.DTMESCOMPETENC), 'YEAR') = TRUNC(TO_DATE(:P_DTMESCOMPETENC), 'YEAR')
                AND EC.NRENVIOEXCL IS NULL
                AND ESH.NRESTRUTURAM IS NOT NULL
                AND EC.IDATIVO = 'S'
                AND EC.NREVENTO IN (SELECT SE.NREVENTO
                                      FROM ESO_EVENTO SE
                                     WHERE SE.NMEVENTO = 'S-1200')) ENVIODT ON ENVIODT.NRCHAVE = VM.NRPESSOA 
                                                                           AND ENVIODT.NRORG = VM.NRORG
                                                                           AND ENVIODT.NRTABELA  = CF.NRTIPOMOVIMENT
                                                                           AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12'
                                                                           AND CF.NROCORRECAL = 1                      
  /*Busca rescisão anterior em caso de complementar*/
  LEFT JOIN (SELECT /*+ INDEX (ITC FPA_ITECALCFOLHA_UK1)*/ ITC.NRORG, ITC.NRVINCULOM, MAX(ITC.DTOCORRENCIA) DTOCORRENCIA, CFC.DTOCORRENCIA DTOCORRENCIACALC
               FROM FPA_ITECALCFOLHA ITC
               JOIN FPA_CALCULOFOLHA CFC ON CFC.NRORG = ITC.NRORG
   			   						    AND CFC.DTOCORRENCIA BETWEEN ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC), 'YEAR'),-12) AND :P_DTMESCOMPETENC
                                        AND CFC.NRCALCULOFOLHA = ITC.NRCALCULOFOLHA
                                        AND CFC.NRTIPOMOVIMENT = 1
                                        AND CFC.NRTPMODALIDCAL = 1
              WHERE ITC.NRORG = :P_NRORG
                AND ITC.NREVENTOM = 3050
                AND TRUNC(ITC.DTOCORRENCIA,'MONTH') < :P_DTOCORRENCIA
              GROUP BY ITC.NRORG, ITC.NRVINCULOM, CFC.DTOCORRENCIA) RESC ON RESC.NRORG = IT.NRORG
                                                                        AND RESC.NRVINCULOM = IT.NRVINCULOM
                                                                        AND RESC.DTOCORRENCIACALC < CF.DTOCORRENCIA
   /*Busca cálculo para verificar se é um adiantamento com rescisão*/
   LEFT JOIN (SELECT /*+ INDEX (ITC FPA_ITECALCFOLHA_UK1)*/ ITC.NRORG, ITC.NRVINCULOM, MAX(ITC.DTOCORRENCIA) DTOCORRENCIA, CFC.NRCALCULOFOLHA
               FROM FPA_ITECALCFOLHA ITC
               JOIN FPA_CALCULOFOLHA CFC ON CFC.NRORG = ITC.NRORG
                                        AND CFC.DTOCORRENCIA BETWEEN ADD_MONTHS(TO_DATE(:P_DTMESCOMPETENC),-3) AND :P_DTMESCOMPETENC
                                        AND CFC.NRCALCULOFOLHA = ITC.NRCALCULOFOLHA
                                        AND CFC.NRTIPOMOVIMENT = 1
                                        AND CFC.NRTPMODALIDCAL = 1
              WHERE ITC.NRORG = :P_NRORG
                AND ITC.NREVENTOM = 3050
              GROUP BY ITC.NRORG, ITC.NRVINCULOM, ITC.DTOCORRENCIA, CFC.NRCALCULOFOLHA) CALCULORESC ON CALCULORESC.NRORG = IT.NRORG
                                                                                                   AND CALCULORESC.NRVINCULOM = IT.NRVINCULOM
                                                                                                   AND TRUNC(CALCULORESC.DTOCORRENCIA,'MONTH') = TRUNC(CF.DTOCORRENCIA,'MONTH')
  LEFT JOIN ENDERECOPARC EP ON EP.NRORG = VM.NRORG
                           AND EP.NRPARCNEGOCIO = :P_NRPARCNEGOCIO
                           AND EP.CDTIPOENDERECO = 'PRINCIPAL'
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRPESSOA = :P_NRPESSOA
   AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
   AND (((VM.DTRESCISAOVINC IS NULL OR VM.DTRESCISAOVINC >= :P_DTMESCOMPETENC) AND IT.NREVENTOM = 3030) OR (VM.DTRESCISAOVINC <= LAST_DAY(:P_DTMESCOMPETENC) AND IT.NREVENTOM = 3050))
   AND SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_NRORG_PADRAO" => $this->hcmParameters->getNrorgPadrao(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_INIVALIDADEAMB" => $parametros['INIVALIDADEAMB'],
            "P_NRPESSOA" => $parametros['NRPESSOA'],
            "P_NRPARCNEGOCIO" => $parametros['NRPARCNEGOCIO'],
            "P_NRINSCRICAOPARC" => $parametros['NRINSCRICAOPARC'],
            "P_NRTABELA" => $parametros['NRTABELA'],
            "P_DTOCORRENCIA" => $parametros['DTOCORRENCIA'],
            "P_NRTPAMBIENTE" => $parametros['NRTPAMBIENTE'],
            "P_DTINIMOVIMENTENTR" => $parametros['DTINIMOVIMENTENTR'],
            "P_DTFIMMOVIMENTSAID" => $parametros['DTFIMMOVIMENTSAID'],
            "P_NRCALCULOFOLHALIST" => $calculos['NRCALCULOFOLHALIST'],
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    /**
     * @param $nrorg
     * @param $nrpessoa
     * @param $nrinscricaoparc
     * @param $dtocorrencia
     * @param $nrtpambiente
     * @return array    Associative array
     */
    public function getDadosS1210detPgtoFl($nrorg, $nrpessoa, $nrinscricaoparc, $nrtabela, $dtocorrencia, $nrtpambiente, $tppgto, $inivalidadeamb, $dtocorrecalc) {
        $sql = <<<SQL
/*getDadosS1210detPgtoFl*/
/*Pessoas sem transferência*/
SELECT DECODE(IT.NREVENTOM,3050,CASE WHEN VM.DTRESCISAOVINC <= RESC.DTOCORRENCIA AND TO_CHAR(RESC.DTOCORRENCIACALC,'YYYY-MM') <> TO_CHAR(CF.DTOCORRENCIA,'YYYY-MM') THEN TO_CHAR(CF.DTOCORRENCIA,'YYYY-MM') ELSE ''  END, CASE WHEN ENV.NRRECIBO2 IS NOT NULL AND RESC.DTOCORRENCIA IS NULL AND CF.DTOCORRENCIA = FIRST_DAY(VM.DTRESCISAOVINC) AND ENVIODT.NRENVIO IS NULL THEN '' ELSE DECODE(CF.NRTIPOMOVIMENT,2,'', TO_CHAR(CF.DTOCORRENCIA, CASE WHEN CF.NRTIPOMOVIMENT = 4 AND CF.NROCORRECAL = 1 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' THEN 'YYYY' ELSE 'YYYY-MM' END)) END) perRef,
       CF.NRCALCULOFOLHA ideDmDev,
       'S' indPgtoTt,
       ROUND(DECODE(IT.NREVENTOM,3030,IT.VREVENTOFOLHA,3040,IT.VREVENTOFOLHA,3050,IT.VREVENTOFOLHA,0),2) vrLiq,
       DECODE(IT.NREVENTOM,3050,CASE WHEN VM.DTRESCISAOVINC <= RESC.DTOCORRENCIA AND TO_CHAR(RESC.DTOCORRENCIACALC,'YYYY-MM') <> TO_CHAR(CF.DTOCORRENCIA,'YYYY-MM') THEN '' ELSE ENV.NRRECIBO2 END,CASE WHEN ENV.NRRECIBO2 IS NOT NULL AND RESC.DTOCORRENCIA IS NULL AND CF.DTOCORRENCIA = FIRST_DAY(VM.DTRESCISAOVINC) AND ENVIODT.NRENVIO IS NULL  THEN ENV.NRRECIBO2 ELSE '' END) nrRecArq,
       /*retPgtoTot getDadosS1210retPgtoTot*/
       /*infoPgtoParc*/
       VM.NRORG, VM.NRPESSOA, CF.NRCALCULOFOLHA, CF.NRTIPOMOVIMENT, :P_NRINSCRICAOPARC NRINSCRICAOPARC
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Movimentação de entrada*/
  LEFT JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT, MO.DTINIMOVIMENT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 8
                AND SUBSTR(EH.CDCNPJESTRUT,1,8) <> SUBSTR(:P_NRINSCRICAOPARC,1,8)
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHN ON EHN.NRORG = VH.NRORG
                                                                                                   AND EHN.NRVINCULOM = VH.NRVINCULOM
  /*Movimentacao de saida*/
  LEFT JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT, MO.DTINIMOVIMENT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 9
                AND SUBSTR(EH.CDCNPJESTRUT,1,8) <> SUBSTR(:P_NRINSCRICAOPARC,1,8)
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHS ON EHS.NRORG = VH.NRORG
                                                                                                   AND EHS.NRVINCULOM = VH.NRVINCULOM
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = VH.NRORG
                          AND IT.NRVINCULOM = VH.NRVINCULOM
                          AND IT.NREVENTOM IN (3030,3050)
                          AND IT.DTOCORRENCIA = :P_DTOCORRENCIA
  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = IT.NRORG
                          AND CF.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
                          AND CF.NRTIPOMOVIMENT IN (1,4,10,19)
                          AND CF.NRTPMODALIDCAL = 1
  /*Busca rescisão anterior em caso de complementar*/
  LEFT JOIN (SELECT ITC.NRORG, ITC.NRVINCULOM, MAX(ITC.DTOCORRENCIA) DTOCORRENCIA, MAX(CFC.DTOCORRENCIA) DTOCORRENCIACALC
               FROM FPA_ITECALCFOLHA ITC
               JOIN FPA_CALCULOFOLHA CFC ON CFC.NRORG = ITC.NRORG
                                        AND CFC.NRCALCULOFOLHA = ITC.NRCALCULOFOLHA
                                        AND CFC.NRTIPOMOVIMENT = 1
                                        AND CFC.NRTPMODALIDCAL = 1
              WHERE ITC.NRORG = :P_NRORG
                AND ITC.NREVENTOM = 3050
                AND TRUNC(CFC.DTOCORRENCIA,'MONTH') < TRUNC(TO_DATE(:P_DTOCORRECALC),'MONTH')
              GROUP BY ITC.NRORG, ITC.NRVINCULOM) RESC ON RESC.NRORG = IT.NRORG
                                                      AND RESC.NRVINCULOM = IT.NRVINCULOM
   LEFT JOIN (SELECT ITC.NRORG, ITC.NRVINCULOM, MAX(TRUNC(ITC.DTOCORRENCIA,'MONTH')) DTOCORRENCIA
               FROM FPA_ITECALCFOLHA ITC
               JOIN FPA_CALCULOFOLHA CFC ON CFC.NRORG = ITC.NRORG
                                        AND CFC.NRCALCULOFOLHA = ITC.NRCALCULOFOLHA
                                        AND CFC.NRTIPOMOVIMENT = 1
                                        AND CFC.NRTPMODALIDCAL = 1
              WHERE ITC.NRORG = :P_NRORG
                AND ITC.NREVENTOM = 3050
              GROUP BY ITC.NRORG, ITC.NRVINCULOM) CALCULORESC ON CALCULORESC.NRORG = IT.NRORG
                                                             AND CALCULORESC.NRVINCULOM = IT.NRVINCULOM
                                                             AND CALCULORESC.DTOCORRENCIA = TRUNC(CF.DTOCORRENCIA,'MONTH')
  LEFT JOIN ESO_ENVIOCADASTROS ENV ON ENV.NRORG = VM.NRORG
                                  AND ENV.NRESTRUTURAM = VH.NRESTRUTLEGAL
                                  AND ENV.NRCHAVE = VM.NRVINCULOM
                                  AND ENV.NRTPAMBIENTE = :P_NRTPAMBIENTE
                                  AND ENV.IDATIVO = 'S'
                                  AND (ENV.IDSTATUS = 'C' OR ENV.IDSTATUS = 'A')
                                  AND ENV.NRENVIOEXCL IS NULL
                                  AND ENV.NREVENTO IN (SELECT EVE.NREVENTO FROM ESO_EVENTO EVE
                                                        WHERE EVE.NREVENTO = ENV.NREVENTO
                                                          AND EVE.NMEVENTO = DECODE(VM.NRTIPOVINCULOM,1,'S-2299','S-2399'))
  /*Verifica se o 13 foi enviado no S-1200 ou no S-2299*/
  LEFT JOIN (SELECT EC.*
               FROM ESO_ENVIOCADASTROS EC
               LEFT JOIN ESTRUTURAH ESH ON ESH.NRORG = EC.NRORG
                                  AND ESH.NRESTRUTURAM = EC.NRESTRUTURAM
                                  AND SUBSTR(ESH.CDCNPJESTRUT, 1, 8) =  SUBSTR(:P_NRINSCRICAOPARC, 1,8)
                                  AND ESH.DTMESCOMPETENC = (SELECT MAX(ESHH.DTMESCOMPETENC)
                                                              FROM ESTRUTURAH ESHH
                                                             WHERE ESHH.NRORG = ESH.NRORG
                                                               AND ESHH.NRESTRUTURAM = ESH.NRESTRUTURAM
                                                               AND ESHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE EC.IDSTATUS IN ('C', 'A')
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
                AND EC.NRTABELA = 4
                AND TRUNC(TO_DATE(EC.DTMESCOMPETENC), 'YEAR') = TRUNC(TO_DATE(:P_DTMESCOMPETENC), 'YEAR')
                AND EC.NRENVIOEXCL IS NULL
                AND ESH.NRESTRUTURAM IS NOT NULL
                AND EC.IDATIVO = 'S'
                AND EC.NREVENTO IN (SELECT SE.NREVENTO
                                      FROM ESO_EVENTO SE
                                     WHERE SE.NMEVENTO = 'S-1200')) ENVIODT ON ENVIODT.NRCHAVE = VM.NRPESSOA 
                                                                           AND ENVIODT.NRORG = VM.NRORG
                                                                           AND ENVIODT.NRTABELA  = CF.NRTIPOMOVIMENT
                                                                           AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12'
                                                                           AND CF.NROCORRECAL = 1                                                          
 WHERE VM.NRORG = :P_NRORG
   AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
   AND VM.NRPESSOA = :P_NRPESSOA
   AND SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
   AND EHN.DTINIMOVIMENT IS NULL AND EHS.DTINIMOVIMENT IS NULL
   AND DECODE(IT.NREVENTOM,3050,CASE 
                           WHEN VM.DTRESCISAOVINC < :P_INIVALIDADEAMB THEN '9' 
                           WHEN VM.DTRESCISAOVINC <= RESC.DTOCORRENCIA THEN '1' 
                           ELSE DECODE(VM.NRTIPOVINCULOM,1,'2','3') END,
                         CASE 
                           WHEN CF.DTOCORRENCIA < TRUNC(TO_DATE(:P_INIVALIDADEAMB),'MM') THEN '9' 
                           WHEN (CALCULORESC.DTOCORRENCIA IS NOT NULL OR TRUNC(TO_DATE(VM.DTRESCISAOVINC),'MONTH') = TO_DATE(CF.DTOCORRENCIA))  AND CF.NRTIPOMOVIMENT <> 2 AND ENVIODT.NRENVIO IS NULL THEN DECODE(VM.NRTIPOVINCULOM,1,'2','3') 
                           ELSE DECODE(CF.NRTIPOMOVIMENT,2,'7','1') END) = :P_TPPGTO
   AND EXISTS(SELECT 1 
                FROM FPA_ITECALCFOLHA ITC
                JOIN FPA_EVENTOH EH ON EH.NREVENTOM = ITC.NREVENTOM
                                   AND (EH.NRORG = ITC.NRORG OR EH.NRORG = 0)
                                   AND EH.DTMESCOMPETENC = (SELECT MAX(EHH.DTMESCOMPETENC)
                                                              FROM FPA_EVENTOH EHH
                                                             WHERE EHH.NREVENTOM = EH.NREVENTOM
                                                               AND EHH.NRORG = EH.NRORG
                                                               AND EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
                JOIN NATUREZARUBRICA NR ON NR.NRNATURUBR = EH.NRNATURUBR
               WHERE ITC.NRORG = IT.NRORG
                 AND ITC.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
                 AND ITC.NRVINCULOM = IT.NRVINCULOM
                 AND ITC.VREVENTOFOLHA > 0
                 AND ((ITC.IDEVENDEMONCALC = 'N' AND EH.IDEVENTODEMONST = 'N') OR (EH.IDEVENTODEMONST = 'S')) )
UNION ALL
/*Pessoas com tranferência de saída na competência*/
SELECT DECODE(IT.NREVENTOM,3050,CASE WHEN VM.DTRESCISAOVINC <= RESC.DTOCORRENCIA AND TO_CHAR(RESC.DTOCORRENCIACALC,'YYYY-MM') <> TO_CHAR(CF.DTOCORRENCIA,'YYYY-MM') THEN TO_CHAR(CF.DTOCORRENCIA,'YYYY-MM') ELSE '' END, CASE WHEN ENV.NRRECIBO2 IS NOT NULL AND RESC.DTOCORRENCIA IS NULL AND CF.DTOCORRENCIA = FIRST_DAY(VM.DTRESCISAOVINC) AND ENVIODT.NRENVIO IS NULL THEN '' ELSE DECODE(CF.NRTIPOMOVIMENT,2,'',TO_CHAR(CF.DTOCORRENCIA, DECODE(CF.NRTIPOMOVIMENT,4,DECODE(TO_CHAR(CF.DTOCORRENCIA,'MM'),'12','YYYY','YYYY-MM'),'YYYY-MM')))END) perRef,
       CF.NRCALCULOFOLHA ideDmDev,
       'S' indPgtoTt,
       ROUND(DECODE(IT.NREVENTOM,3030,IT.VREVENTOFOLHA,3040,IT.VREVENTOFOLHA,3050,IT.VREVENTOFOLHA,0),2) vrLiq,
       DECODE(IT.NREVENTOM,3050,CASE WHEN VM.DTRESCISAOVINC <= RESC.DTOCORRENCIA AND TO_CHAR(RESC.DTOCORRENCIACALC,'YYYY-MM') <> TO_CHAR(CF.DTOCORRENCIA,'YYYY-MM') THEN '' ELSE ENV.NRRECIBO2 END,CASE WHEN ENV.NRRECIBO2 IS NOT NULL AND RESC.DTOCORRENCIA IS NULL AND CF.DTOCORRENCIA = FIRST_DAY(VM.DTRESCISAOVINC) AND ENVIODT.NRENVIO IS NULL THEN ENV.NRRECIBO2 ELSE '' END) nrRecArq,
       /*retPgtoTot getDadosS1210retPgtoTot*/
       /*infoPgtoParc*/
       VM.NRORG, VM.NRPESSOA, CF.NRCALCULOFOLHA, CF.NRTIPOMOVIMENT, :P_NRINSCRICAOPARC NRINSCRICAOPARC
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Movimentacao de saida*/
  JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 9
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHS ON EHS.NRORG = VH.NRORG
                                                                                                  AND EHS.NRVINCULOM = VH.NRVINCULOM
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = VH.NRORG
                          AND IT.NRVINCULOM = VH.NRVINCULOM
                          AND IT.NREVENTOM IN (3030,3050)
                          AND IT.DTOCORRENCIA = :P_DTOCORRENCIA
  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = IT.NRORG
                          AND CF.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
                          AND CF.NRTIPOMOVIMENT IN (1,4,10,19)
                          AND CF.NRTPMODALIDCAL = 1
                          AND CF.DTOCORRENCIA = TRUNC(EHS.DTFIMMOVIMENT,'MONTH')
  /*Busca rescisão anterior em caso de complementar*/
  LEFT JOIN (SELECT ITC.NRORG, ITC.NRVINCULOM, MAX(ITC.DTOCORRENCIA) DTOCORRENCIA, MAX(CFC.DTOCORRENCIA) DTOCORRENCIACALC
               FROM FPA_ITECALCFOLHA ITC
               JOIN FPA_CALCULOFOLHA CFC ON CFC.NRORG = ITC.NRORG
                                        AND CFC.NRCALCULOFOLHA = ITC.NRCALCULOFOLHA
                                        AND CFC.NRTIPOMOVIMENT = 1
                                        AND CFC.NRTPMODALIDCAL = 1
              WHERE ITC.NRORG = :P_NRORG
                AND ITC.NREVENTOM = 3050
                AND TRUNC(ITC.DTOCORRENCIA,'MONTH') < TRUNC(TO_DATE(:P_DTOCORRECALC),'MONTH')
              GROUP BY ITC.NRORG, ITC.NRVINCULOM) RESC ON RESC.NRORG = IT.NRORG
                                                      AND RESC.NRVINCULOM = IT.NRVINCULOM
  /*Busca cálculo para verificar se é um adiantamento com rescisão*/
   LEFT JOIN (SELECT ITC.NRORG, ITC.NRVINCULOM, MAX(TRUNC(ITC.DTOCORRENCIA,'MONTH')) DTOCORRENCIA
               FROM FPA_ITECALCFOLHA ITC
               JOIN FPA_CALCULOFOLHA CFC ON CFC.NRORG = ITC.NRORG
                                        AND CFC.NRCALCULOFOLHA = ITC.NRCALCULOFOLHA
                                        AND CFC.NRTIPOMOVIMENT = 1
                                        AND CFC.NRTPMODALIDCAL = 1
              WHERE ITC.NRORG = :P_NRORG
                AND ITC.NREVENTOM = 3050
              GROUP BY ITC.NRORG, ITC.NRVINCULOM) CALCULORESC ON CALCULORESC.NRORG = IT.NRORG
                                                             AND CALCULORESC.NRVINCULOM = IT.NRVINCULOM
                                                             AND CALCULORESC.DTOCORRENCIA = TRUNC(CF.DTOCORRENCIA,'MONTH')
  LEFT JOIN ESO_ENVIOCADASTROS ENV ON ENV.NRORG = VM.NRORG
                                  AND ENV.NRESTRUTURAM = VH.NRESTRUTLEGAL
                                  AND ENV.NRCHAVE = VM.NRVINCULOM
                                  AND ENV.NRTPAMBIENTE = :P_NRTPAMBIENTE
                                  AND ENV.IDATIVO = 'S'
                                  AND (ENV.IDSTATUS = 'C' OR ENV.IDSTATUS = 'A')
                                  AND ENV.NRENVIOEXCL IS NULL
                                  AND ENV.NREVENTO IN (SELECT EVE.NREVENTO FROM ESO_EVENTO EVE
                                                        WHERE EVE.NREVENTO = ENV.NREVENTO
                                                          AND EVE.NMEVENTO = DECODE(VM.NRTIPOVINCULOM,1,'S-2299','S-2399'))
  /*Verifica se o 13 foi enviado no S-1200 ou no S-2299*/
  LEFT JOIN (SELECT EC.*
               FROM ESO_ENVIOCADASTROS EC
               LEFT JOIN ESTRUTURAH ESH ON ESH.NRORG = EC.NRORG
                                  AND ESH.NRESTRUTURAM = EC.NRESTRUTURAM
                                  AND SUBSTR(ESH.CDCNPJESTRUT, 1, 8) =  SUBSTR(:P_NRINSCRICAOPARC, 1,8)
                                  AND ESH.DTMESCOMPETENC = (SELECT MAX(ESHH.DTMESCOMPETENC)
                                                              FROM ESTRUTURAH ESHH
                                                             WHERE ESHH.NRORG = ESH.NRORG
                                                               AND ESHH.NRESTRUTURAM = ESH.NRESTRUTURAM
                                                               AND ESHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE EC.IDSTATUS IN ('C', 'A')
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
                AND EC.NRTABELA = 4
                AND TRUNC(TO_DATE(EC.DTMESCOMPETENC), 'YEAR') = TRUNC(TO_DATE(:P_DTMESCOMPETENC), 'YEAR')
                AND EC.NRENVIOEXCL IS NULL
                AND ESH.NRESTRUTURAM IS NOT NULL
                AND EC.IDATIVO = 'S'
                AND EC.NREVENTO IN (SELECT SE.NREVENTO
                                      FROM ESO_EVENTO SE
                                     WHERE SE.NMEVENTO = 'S-1200')) ENVIODT ON ENVIODT.NRCHAVE = VM.NRPESSOA 
                                                                           AND ENVIODT.NRORG = VM.NRORG
                                                                           AND ENVIODT.NRTABELA  = CF.NRTIPOMOVIMENT
                                                                           AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12'
                                                                           AND CF.NROCORRECAL = 1                                                        
 WHERE VM.NRORG = :P_NRORG
   AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
   AND VM.NRPESSOA = :P_NRPESSOA
   AND SUBSTR(EHS.CDCNPJESTRUT,1,8) <> SUBSTR(EH.CDCNPJESTRUT,1,8)
   AND SUBSTR(EHS.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
   AND DECODE(IT.NREVENTOM,3050,CASE 
                           WHEN VM.DTRESCISAOVINC < :P_INIVALIDADEAMB THEN '9' 
                           WHEN VM.DTRESCISAOVINC <= RESC.DTOCORRENCIA THEN '1' 
                           ELSE DECODE(VM.NRTIPOVINCULOM,1,'2','3') END,
                         CASE 
                           WHEN CF.DTOCORRENCIA < TRUNC(TO_DATE(:P_INIVALIDADEAMB),'MM') THEN '9' 
                           WHEN (CALCULORESC.DTOCORRENCIA IS NOT NULL OR TRUNC(TO_DATE(VM.DTRESCISAOVINC),'MONTH') = TO_DATE(CF.DTOCORRENCIA))  AND CF.NRTIPOMOVIMENT <> 2 AND ENVIODT.NRENVIO IS NULL THEN DECODE(VM.NRTIPOVINCULOM,1,'2','3') 
                           ELSE DECODE(CF.NRTIPOMOVIMENT,2,'7','1') END) = :P_TPPGTO
   AND EXISTS(SELECT 1 
                FROM FPA_ITECALCFOLHA ITC
                JOIN FPA_EVENTOH EH ON EH.NREVENTOM = ITC.NREVENTOM
                                   AND (EH.NRORG = ITC.NRORG OR EH.NRORG = 0)
                                   AND EH.DTMESCOMPETENC = (SELECT MAX(EHH.DTMESCOMPETENC)
                                                              FROM FPA_EVENTOH EHH
                                                             WHERE EHH.NREVENTOM = EH.NREVENTOM
                                                               AND EHH.NRORG = EH.NRORG
                                                               AND EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
                JOIN NATUREZARUBRICA NR ON NR.NRNATURUBR = EH.NRNATURUBR
               WHERE ITC.NRORG = IT.NRORG
                 AND ITC.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
                 AND ITC.NRVINCULOM = IT.NRVINCULOM
                 AND ITC.VREVENTOFOLHA > 0
                 AND ((ITC.IDEVENDEMONCALC = 'N' AND EH.IDEVENTODEMONST = 'N') OR (EH.IDEVENTODEMONST = 'S')) )
UNION ALL
/*Pessoas com tranferência de entrada na competência*/
SELECT DECODE(IT.NREVENTOM,3050,CASE WHEN VM.DTRESCISAOVINC <= RESC.DTOCORRENCIA AND TO_CHAR(RESC.DTOCORRENCIACALC,'YYYY-MM') <> TO_CHAR(CF.DTOCORRENCIA,'YYYY-MM') THEN TO_CHAR(CF.DTOCORRENCIA,'YYYY-MM') ELSE '' END, CASE WHEN ENV.NRRECIBO2 IS NOT NULL AND RESC.DTOCORRENCIA IS NULL AND CF.DTOCORRENCIA = FIRST_DAY(VM.DTRESCISAOVINC) AND ENVIODT.NRENVIO IS NULL THEN '' ELSE DECODE(CF.NRTIPOMOVIMENT,2,'',TO_CHAR(CF.DTOCORRENCIA, DECODE(CF.NRTIPOMOVIMENT,4,DECODE(TO_CHAR(CF.DTOCORRENCIA,'MM'),'12','YYYY','YYYY-MM'),'YYYY-MM')))END) perRef,
       CF.NRCALCULOFOLHA ideDmDev,
       'S' indPgtoTt,
       ROUND(DECODE(IT.NREVENTOM,3030,IT.VREVENTOFOLHA,3040,IT.VREVENTOFOLHA,3050,IT.VREVENTOFOLHA,0),2) vrLiq,
       DECODE(IT.NREVENTOM,3050,CASE WHEN VM.DTRESCISAOVINC <= RESC.DTOCORRENCIA AND TO_CHAR(RESC.DTOCORRENCIACALC,'YYYY-MM') <> TO_CHAR(CF.DTOCORRENCIA,'YYYY-MM') THEN '' ELSE ENV.NRRECIBO2 END,CASE WHEN ENV.NRRECIBO2 IS NOT NULL AND RESC.DTOCORRENCIA IS NULL AND CF.DTOCORRENCIA = FIRST_DAY(VM.DTRESCISAOVINC) AND ENVIODT.NRENVIO IS NULL THEN ENV.NRRECIBO2 ELSE '' END) nrRecArq,
       /*retPgtoTot getDadosS1210retPgtoTot*/
       /*infoPgtoParc*/
       VM.NRORG, VM.NRPESSOA, CF.NRCALCULOFOLHA, CF.NRTIPOMOVIMENT, :P_NRINSCRICAOPARC NRINSCRICAOPARC
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Movimentação de entrada*/
  JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT, MO.DTINIMOVIMENT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 8
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHN ON EHN.NRORG = VH.NRORG
                                                                                                   AND EHN.NRVINCULOM = VH.NRVINCULOM
                                                                                                   AND SUBSTR(EHN.CDCNPJESTRUT,1,8) = SUBSTR(EH.CDCNPJESTRUT,1,8)
  /*Movimentacao de saida*/
  JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT, MO.DTINIMOVIMENT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 9
                AND SUBSTR(EH.CDCNPJESTRUT,1,8) <> SUBSTR(:P_NRINSCRICAOPARC,1,8)
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHS ON EHS.NRORG = VH.NRORG
                                                                                                   AND EHS.NRVINCULOM = VH.NRVINCULOM
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = VH.NRORG
                          AND IT.NRVINCULOM = VH.NRVINCULOM
                          AND IT.NREVENTOM IN (3030,3050)
                          AND IT.DTOCORRENCIA = :P_DTOCORRENCIA
  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = IT.NRORG
                          AND CF.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
                          AND CF.NRTIPOMOVIMENT IN (1,4,10,19)
                          AND CF.NRTPMODALIDCAL = 1
                          AND (EHN.DTINIMOVIMENT IS NOT NULL AND CF.DTOCORRENCIA = FIRST_DAY(TO_DATE(:P_DTOCORRENCIA)))
  /*Busca rescisão anterior em caso de complementar*/
  LEFT JOIN (SELECT ITC.NRORG, ITC.NRVINCULOM, MAX(ITC.DTOCORRENCIA) DTOCORRENCIA, MAX(CFC.DTOCORRENCIA) DTOCORRENCIACALC
               FROM FPA_ITECALCFOLHA ITC
               JOIN FPA_CALCULOFOLHA CFC ON CFC.NRORG = ITC.NRORG
                                        AND CFC.NRCALCULOFOLHA = ITC.NRCALCULOFOLHA
                                        AND CFC.NRTIPOMOVIMENT = 1
                                        AND CFC.NRTPMODALIDCAL = 1
              WHERE ITC.NRORG = :P_NRORG
                AND ITC.NREVENTOM = 3050
                AND TRUNC(ITC.DTOCORRENCIA,'MONTH') < TRUNC(TO_DATE(:P_DTOCORRECALC),'MONTH')
              GROUP BY ITC.NRORG, ITC.NRVINCULOM) RESC ON RESC.NRORG = IT.NRORG
                                                      AND RESC.NRVINCULOM = IT.NRVINCULOM
  /*Busca cálculo para verificar se é um adiantamento com rescisão*/
   LEFT JOIN (SELECT ITC.NRORG, ITC.NRVINCULOM, MAX(TRUNC(ITC.DTOCORRENCIA,'MONTH')) DTOCORRENCIA
               FROM FPA_ITECALCFOLHA ITC
               JOIN FPA_CALCULOFOLHA CFC ON CFC.NRORG = ITC.NRORG
                                        AND CFC.NRCALCULOFOLHA = ITC.NRCALCULOFOLHA
                                        AND CFC.NRTIPOMOVIMENT = 1
                                        AND CFC.NRTPMODALIDCAL = 1
              WHERE ITC.NRORG = :P_NRORG
                AND ITC.NREVENTOM = 3050
              GROUP BY ITC.NRORG, ITC.NRVINCULOM) CALCULORESC ON CALCULORESC.NRORG = IT.NRORG
                                                             AND CALCULORESC.NRVINCULOM = IT.NRVINCULOM
                                                             AND CALCULORESC.DTOCORRENCIA = TRUNC(CF.DTOCORRENCIA,'MONTH')
  LEFT JOIN ESO_ENVIOCADASTROS ENV ON ENV.NRORG = VM.NRORG
                                  AND ENV.NRESTRUTURAM = VH.NRESTRUTLEGAL
                                  AND ENV.NRCHAVE = VM.NRVINCULOM
                                  AND ENV.NRTPAMBIENTE = :P_NRTPAMBIENTE
                                  AND ENV.IDATIVO = 'S'
                                  AND (ENV.IDSTATUS = 'C' OR ENV.IDSTATUS = 'A')
                                  AND ENV.NRENVIOEXCL IS NULL
                                  AND ENV.NREVENTO IN (SELECT EVE.NREVENTO FROM ESO_EVENTO EVE
                                                        WHERE EVE.NREVENTO = ENV.NREVENTO
                                                          AND EVE.NMEVENTO = DECODE(VM.NRTIPOVINCULOM,1,'S-2299','S-2399'))
  /*Verifica se o 13 foi enviado no S-1200 ou no S-2299*/
  LEFT JOIN (SELECT EC.*
               FROM ESO_ENVIOCADASTROS EC
               LEFT JOIN ESTRUTURAH ESH ON ESH.NRORG = EC.NRORG
                                  AND ESH.NRESTRUTURAM = EC.NRESTRUTURAM
                                  AND SUBSTR(ESH.CDCNPJESTRUT, 1, 8) =  SUBSTR(:P_NRINSCRICAOPARC, 1,8)
                                  AND ESH.DTMESCOMPETENC = (SELECT MAX(ESHH.DTMESCOMPETENC)
                                                              FROM ESTRUTURAH ESHH
                                                             WHERE ESHH.NRORG = ESH.NRORG
                                                               AND ESHH.NRESTRUTURAM = ESH.NRESTRUTURAM
                                                               AND ESHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE EC.IDSTATUS IN ('C', 'A')
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
                AND EC.NRTABELA = 4
                AND TRUNC(TO_DATE(EC.DTMESCOMPETENC), 'YEAR') = TRUNC(TO_DATE(:P_DTMESCOMPETENC), 'YEAR')
                AND EC.NRENVIOEXCL IS NULL
                AND ESH.NRESTRUTURAM IS NOT NULL
                AND EC.IDATIVO = 'S'
                AND EC.NREVENTO IN (SELECT SE.NREVENTO
                                      FROM ESO_EVENTO SE
                                     WHERE SE.NMEVENTO = 'S-1200')) ENVIODT ON ENVIODT.NRCHAVE = VM.NRPESSOA 
                                                                           AND ENVIODT.NRORG = VM.NRORG
                                                                           AND ENVIODT.NRTABELA  = CF.NRTIPOMOVIMENT
                                                                           AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12'
                                                                           AND CF.NROCORRECAL = 1                                                          
 WHERE VM.NRORG = :P_NRORG
   AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
   AND VM.NRPESSOA = :P_NRPESSOA
   AND SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
   AND DECODE(IT.NREVENTOM,3050,CASE 
                           WHEN VM.DTRESCISAOVINC < :P_INIVALIDADEAMB THEN '9' 
                           WHEN VM.DTRESCISAOVINC <= RESC.DTOCORRENCIA THEN '1' 
                           ELSE DECODE(VM.NRTIPOVINCULOM,1,'2','3') END,
                         CASE 
                           WHEN CF.DTOCORRENCIA < TRUNC(TO_DATE(:P_INIVALIDADEAMB),'MM') THEN '9' 
                           WHEN (CALCULORESC.DTOCORRENCIA IS NOT NULL OR TRUNC(TO_DATE(VM.DTRESCISAOVINC),'MONTH') = TO_DATE(CF.DTOCORRENCIA))  AND CF.NRTIPOMOVIMENT <> 2 AND ENVIODT.NRENVIO IS NULL THEN DECODE(VM.NRTIPOVINCULOM,1,'2','3') 
                           ELSE DECODE(CF.NRTIPOMOVIMENT,2,'7','1') END) = :P_TPPGTO
   AND EXISTS(SELECT 1 
                FROM FPA_ITECALCFOLHA ITC
                JOIN FPA_EVENTOH EH ON EH.NREVENTOM = ITC.NREVENTOM
                                   AND (EH.NRORG = ITC.NRORG OR EH.NRORG = 0)
                                   AND EH.DTMESCOMPETENC = (SELECT MAX(EHH.DTMESCOMPETENC)
                                                              FROM FPA_EVENTOH EHH
                                                             WHERE EHH.NREVENTOM = EH.NREVENTOM
                                                               AND EHH.NRORG = EH.NRORG
                                                               AND EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
                JOIN NATUREZARUBRICA NR ON NR.NRNATURUBR = EH.NRNATURUBR
               WHERE ITC.NRORG = IT.NRORG
                 AND ITC.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
                 AND ITC.NRVINCULOM = IT.NRVINCULOM
                 AND ITC.VREVENTOFOLHA > 0
                 AND ((ITC.IDEVENDEMONCALC = 'N' AND EH.IDEVENTODEMONST = 'N') OR (EH.IDEVENTODEMONST = 'S')) )
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRPESSOA" => $nrpessoa,
            "P_NRINSCRICAOPARC" => $nrinscricaoparc,
            "P_DTOCORRENCIA" => $dtocorrencia,
            "P_NRTPAMBIENTE" => $nrtpambiente,
            "P_TPPGTO" => $tppgto,
            "P_INIVALIDADEAMB" => $inivalidadeamb,
            "P_DTOCORRECALC" => $dtocorrecalc
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    /**
     * @param $nrorg
     * @param $nrpessoa
     * @param $nrinscricaoparc
     * @param $nrcalculofolha
     * @return array    Associative array
     */
    public function getDadosS1210retPgtoTot($nrorg, $nrpessoa, $nrinscricaoparc, $nrcalculofolha, $nrtipomoviment) {
        $sql = <<<SQL
/*getDadosS1210retPgtoTot*/
/*Pessoas sem transferência*/
SELECT IT.NREVENTOM AS codRubr,
       :P_NRTIPOMOVIMENT AS ideTabrubr,
       ROUND(DECODE(IT.VRREFFOLHA, 0, '', IT.VRREFFOLHA),2) AS qtdRubr,
       ROUND(EVH.VRPERCENTUALEVENTO,2) AS fatorRubr,
       ROUND(DECODE(IT.VRREFFOLHA, 0, '', (IT.VREVENTOFOLHA / IT.VRREFFOLHA)),2) AS vrUnit,
       ROUND(IT.VREVENTOFOLHA,2) AS vrRubr,
       /*penAlim getDadosS1210penAlim*/
       VM.NRORG, VM.NRPESSOA, IT.NRCALCULOFOLHA, :P_NRINSCRICAOPARC NRINSCRICAOPARC, IT.NREVENTOM
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                         AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                         AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                   WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                     AND H1.NRORG = EH.NRORG
                                                     AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Movimentação de entrada*/
  LEFT JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT, MO.DTINIMOVIMENT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 8
                AND SUBSTR(EH.CDCNPJESTRUT,1,8) <> SUBSTR(:P_NRINSCRICAOPARC,1,8)
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHN ON EHN.NRORG = VH.NRORG
                                                                                                   AND EHN.NRVINCULOM = VH.NRVINCULOM
  /*Movimentacao de saida*/
  LEFT JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT, MO.DTINIMOVIMENT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 9
                AND SUBSTR(EH.CDCNPJESTRUT,1,8) <> SUBSTR(:P_NRINSCRICAOPARC,1,8)
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHS ON EHS.NRORG = VH.NRORG
                                                                                                   AND EHS.NRVINCULOM = VH.NRVINCULOM
  /*Pagamentos*/
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = VH.NRORG
                          AND IT.NRVINCULOM = VH.NRVINCULOM
  /*Rubrica*/
  JOIN FPA_EVENTOM EM ON (EM.NRORG = IT.NRORG OR EM.NRORG = 0)
                     AND EM.NREVENTOM = IT.NREVENTOM
                     /*AND EM.IDTIPOEVENTO IN ('PROVENTO','DESCONTO','ENCARGO')*/
                     /*AND EM.NREVENTOM IN (1300,1310,1320,1330,1331,1332,1340,1350,1360,1370,1380,1390,1395,1400,1410,1420,1430,1435,1440,1450,1452,1460)*/
  JOIN FPA_EVENTOH EVH ON EVH.NRORG = EM.NRORG
                     AND EVH.NREVENTOM = EM.NREVENTOM
                     AND EVH.NRNATURUBR IS NOT NULL
                     AND EVH.DTMESCOMPETENC  = (SELECT MAX(EHH.DTMESCOMPETENC) FROM FPA_EVENTOH EHH
                                                WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND EHH.NREVENTOM = EVH.NREVENTOM
                                                  AND EHH.NRORG = EVH.NRORG)
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRPESSOA = :P_NRPESSOA
   AND SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
   AND EHN.DTINIMOVIMENT IS NULL AND EHS.DTINIMOVIMENT IS NULL
   AND IT.NRCALCULOFOLHA = :P_NRCALCULOFOLHA
   AND IT.VREVENTOFOLHA > 0
   AND ((IT.IDEVENDEMONCALC = 'N' AND EVH.IDEVENTODEMONST = 'N') OR (EVH.IDEVENTODEMONST = 'S')) /*SE NÃO DEMONSTRATIVO NO CADASTRO E DEMONSTRATIVO NA FOLHA NÃO ENVIA*/
   AND (SELECT MAX(INC.CDESOCIAL)
          FROM FPA_INCIDEVENTO IE
          JOIN FPA_TIPOINCIDE TI ON (TI.NRORG = :P_NRORG OR TI.NRORG = 0)
                                AND TI.NRTIPOINCIDE = IE.NRTIPOINCIDE
                                AND INSTR(','||TI.DSNRTIPOMOVIMENT||',',','||:P_NRTIPOMOVIMENT||',') > 0
          JOIN INCIDENCIAIRRF INC ON INSTR(','||INC.DSNRTIPOINCIDE||',',','||TI.NRTIPOINCIDE||',') > 0
                                 AND INC.DSNRTIPOINCIDE IS NOT NULL
         WHERE (IE.NRORG = :P_NRORG OR IE.NRORG = 0)
           AND IE.NREVENTOM = IT.NREVENTOM
           AND (IE.NRTIPOINCIDE IN (SELECT NRTIPOINCIDE 
                                      FROM FPA_GRPITEM 
                                     WHERE NRGRPINCIDE = 47) OR TI.DSNRTIPOMOVIMENT IS NOT NULL)) IN (31, 32, 33, 34, 35, 51, 52, 53, 54, 55, 81, 82, 83) /*codIncIRRF*/
UNION ALL
/*Pessoas com tranferência de saída na competência*/
SELECT IT.NREVENTOM AS codRubr,
       :P_NRTIPOMOVIMENT AS ideTabrubr,
       ROUND(DECODE(IT.VRREFFOLHA, 0, '', IT.VRREFFOLHA),2) AS qtdRubr,
       ROUND(EVH.VRPERCENTUALEVENTO,2) AS fatorRubr,
       ROUND(DECODE(IT.VRREFFOLHA, 0, '', (IT.VREVENTOFOLHA / IT.VRREFFOLHA)),2) AS vrUnit,
       ROUND(IT.VREVENTOFOLHA,2) AS vrRubr,
       /*penAlim getDadosS1210penAlim*/
       VM.NRORG, VM.NRPESSOA, IT.NRCALCULOFOLHA, :P_NRINSCRICAOPARC NRINSCRICAOPARC, IT.NREVENTOM
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                         AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                         AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                   WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                     AND H1.NRORG = EH.NRORG
                                                     AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Movimentacao de saida*/
  JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 9
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHS ON EHS.NRORG = VH.NRORG
                                                                                                  AND EHS.NRVINCULOM = VH.NRVINCULOM
  /*Pagamentos*/
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = VH.NRORG
                          AND IT.NRVINCULOM = VH.NRVINCULOM
  /*Rubrica*/
  JOIN FPA_EVENTOM EM ON (EM.NRORG = IT.NRORG OR EM.NRORG = 0)
                     AND EM.NREVENTOM = IT.NREVENTOM
                     /*AND EM.IDTIPOEVENTO IN ('PROVENTO','DESCONTO','ENCARGO')*/
                     /*AND EM.NREVENTOM IN (1300,1310,1320,1330,1331,1332,1340,1350,1360,1370,1380,1390,1395,1400,1410,1420,1430,1435,1440,1450,1452,1460)*/
  JOIN FPA_EVENTOH EVH ON EVH.NRORG = EM.NRORG
                     AND EVH.NREVENTOM = EM.NREVENTOM
                     AND EVH.NRNATURUBR IS NOT NULL
                     AND EVH.DTMESCOMPETENC  = (SELECT MAX(EHH.DTMESCOMPETENC) FROM FPA_EVENTOH EHH
                                                WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND EHH.NREVENTOM = EVH.NREVENTOM
                                                  AND EHH.NRORG = EVH.NRORG)
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRPESSOA = :P_NRPESSOA
   AND SUBSTR(EHS.CDCNPJESTRUT,1,8) <> SUBSTR(EH.CDCNPJESTRUT,1,8)
   AND SUBSTR(EHS.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
   AND IT.NRCALCULOFOLHA = :P_NRCALCULOFOLHA
   AND IT.VREVENTOFOLHA > 0
   AND ((IT.IDEVENDEMONCALC = 'N' AND EVH.IDEVENTODEMONST = 'N') OR (EVH.IDEVENTODEMONST = 'S')) /*SE NÃO DEMONSTRATIVO NO CADASTRO E DEMONSTRATIVO NA FOLHA NÃO ENVIA*/
   AND (SELECT MAX(INC.CDESOCIAL)
          FROM FPA_INCIDEVENTO IE
          JOIN FPA_TIPOINCIDE TI ON (TI.NRORG = :P_NRORG OR TI.NRORG = 0)
                                AND TI.NRTIPOINCIDE = IE.NRTIPOINCIDE
                                AND INSTR(','||TI.DSNRTIPOMOVIMENT||',',','||:P_NRTIPOMOVIMENT||',') > 0
          JOIN INCIDENCIAIRRF INC ON INSTR(','||INC.DSNRTIPOINCIDE||',',','||TI.NRTIPOINCIDE||',') > 0
                                 AND INC.DSNRTIPOINCIDE IS NOT NULL
         WHERE (IE.NRORG = :P_NRORG OR IE.NRORG = 0)
           AND IE.NREVENTOM = IT.NREVENTOM
           AND (IE.NRTIPOINCIDE IN (SELECT NRTIPOINCIDE 
                                      FROM FPA_GRPITEM 
                                     WHERE NRGRPINCIDE = 47) OR TI.DSNRTIPOMOVIMENT IS NOT NULL)) IN (31, 32, 33, 34, 35, 51, 52, 53, 54, 55, 81, 82, 83) /*codIncIRRF*/
UNION ALL
SELECT IT.NREVENTOM AS codRubr,
       :P_NRTIPOMOVIMENT AS ideTabrubr,
       ROUND(DECODE(IT.VRREFFOLHA, 0, '', IT.VRREFFOLHA),2) AS qtdRubr,
       ROUND(EVH.VRPERCENTUALEVENTO,2) AS fatorRubr,
       ROUND(DECODE(IT.VRREFFOLHA, 0, '', (IT.VREVENTOFOLHA / IT.VRREFFOLHA)),2) AS vrUnit,
       ROUND(IT.VREVENTOFOLHA,2) AS vrRubr,
       /*penAlim getDadosS1210penAlim*/
       VM.NRORG, VM.NRPESSOA, IT.NRCALCULOFOLHA, :P_NRINSCRICAOPARC NRINSCRICAOPARC, IT.NREVENTOM
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                          AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                          AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                    WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                      AND H1.NRORG = EH.NRORG
                                                      AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Movimentação de entrada*/
  JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT, MO.DTINIMOVIMENT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 8
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHN ON EHN.NRORG = VH.NRORG
                                                                                                   AND EHN.NRVINCULOM = VH.NRVINCULOM
                                                                                                   AND SUBSTR(EHN.CDCNPJESTRUT,1,8) = SUBSTR(EH.CDCNPJESTRUT,1,8)
  /*Movimentacao de saida*/
  JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT, MO.DTINIMOVIMENT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 9
                AND SUBSTR(EH.CDCNPJESTRUT,1,8) <> SUBSTR(:P_NRINSCRICAOPARC,1,8)
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHS ON EHS.NRORG = VH.NRORG
                                                                                                   AND EHS.NRVINCULOM = VH.NRVINCULOM
  /*Pagamentos*/
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = VH.NRORG
                          AND IT.NRVINCULOM = VH.NRVINCULOM                      
  /*Rubrica*/
  JOIN FPA_EVENTOM EM ON (EM.NRORG = IT.NRORG OR EM.NRORG = 0)
                     AND EM.NREVENTOM = IT.NREVENTOM
                     /*AND EM.IDTIPOEVENTO IN ('PROVENTO','DESCONTO','ENCARGO')*/
                     /*AND EM.NREVENTOM IN (1300,1310,1320,1330,1331,1332,1340,1350,1360,1370,1380,1390,1395,1400,1410,1420,1430,1435,1440,1450,1452,1460)*/
  JOIN FPA_EVENTOH EVH ON EVH.NRORG = EM.NRORG
                     AND EVH.NREVENTOM = EM.NREVENTOM
                     AND EVH.NRNATURUBR IS NOT NULL
                     AND EVH.DTMESCOMPETENC  = (SELECT MAX(EHH.DTMESCOMPETENC) FROM FPA_EVENTOH EHH
                                                WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND EHH.NREVENTOM = EVH.NREVENTOM
                                                  AND EHH.NRORG = EVH.NRORG)
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRPESSOA = :P_NRPESSOA
   AND SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
   AND IT.NRCALCULOFOLHA = :P_NRCALCULOFOLHA
   AND IT.VREVENTOFOLHA > 0
   AND ((IT.IDEVENDEMONCALC = 'N' AND EVH.IDEVENTODEMONST = 'N') OR (EVH.IDEVENTODEMONST = 'S')) /*SE NÃO DEMONSTRATIVO NO CADASTRO E DEMONSTRATIVO NA FOLHA NÃO ENVIA*/
   AND (SELECT MAX(INC.CDESOCIAL)
          FROM FPA_INCIDEVENTO IE
          JOIN FPA_TIPOINCIDE TI ON (TI.NRORG = :P_NRORG OR TI.NRORG = 0)
                                AND TI.NRTIPOINCIDE = IE.NRTIPOINCIDE
                                AND INSTR(','||TI.DSNRTIPOMOVIMENT||',',','||:P_NRTIPOMOVIMENT||',') > 0
          JOIN INCIDENCIAIRRF INC ON INSTR(','||INC.DSNRTIPOINCIDE||',',','||TI.NRTIPOINCIDE||',') > 0
                                 AND INC.DSNRTIPOINCIDE IS NOT NULL
         WHERE (IE.NRORG = :P_NRORG OR IE.NRORG = 0)
           AND IE.NREVENTOM = IT.NREVENTOM
           AND (IE.NRTIPOINCIDE IN (SELECT NRTIPOINCIDE 
                                      FROM FPA_GRPITEM 
                                     WHERE NRGRPINCIDE = 47) OR TI.DSNRTIPOMOVIMENT IS NOT NULL)) IN (31, 32, 33, 34, 35, 51, 52, 53, 54, 55, 81, 82, 83) /*codIncIRRF*/
 ORDER BY 1
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRPESSOA" => $nrpessoa,
            "P_NRINSCRICAOPARC" => $nrinscricaoparc,
            "P_NRCALCULOFOLHA" => $nrcalculofolha,
            "P_NRTIPOMOVIMENT" => $nrtipomoviment,
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    /**
     * @param $nrorg
     * @param $nrpessoa
     * @param $nrinscricaoparc
     * @param $nrcalculofolha
     * @return array    Associative array
     */
    public function getDadosS1210penAlim($nrorg, $nrpessoa, $nrinscricaoparc, $nrcalculofolha, $nreventom) {
        $sql = <<<SQL
/*getDadosS1210penAlim*/
/*Pessoas sem transferência*/
SELECT PD.NRCPFPESSOA cpfBenef,
       TO_CHAR(PD.DTNASCPESSOA, 'YYYY-MM-DD') dtNasctoBenef,
       PD.NMPESSOA nmBenefic,
       SUM(ROUND(IT.VREVENTOFOLHA,2)) vlrPensao
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Movimentação de entrada*/
  LEFT JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT, MO.DTINIMOVIMENT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 8
                AND SUBSTR(EH.CDCNPJESTRUT,1,8) <> SUBSTR(:P_NRINSCRICAOPARC,1,8)
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHN ON EHN.NRORG = VH.NRORG
                                                                                                   AND EHN.NRVINCULOM = VH.NRVINCULOM
  /*Movimentacao de saida*/
  LEFT JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT, MO.DTINIMOVIMENT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 9
                AND SUBSTR(EH.CDCNPJESTRUT,1,8) <> SUBSTR(:P_NRINSCRICAOPARC,1,8)
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHS ON EHS.NRORG = VH.NRORG
                                                                                                   AND EHS.NRVINCULOM = VH.NRVINCULOM
  /*Beneficiario*/
  JOIN FPA_DEPVINCULO PA ON PA.NRORG = VM.NRORG
                        AND PA.NRVINCULOM = VM.NRVINCULOM
                        AND PA.NRTIPODEPENDE = 3 /*Pensao Judicial*/
  JOIN GPE_PESSOAH PD ON PD.NRORG = PA.NRORG
                     AND PD.NRPESSOA = PA.NRPESSOA
                     AND PD.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH H1
                                                WHERE H1.NRPESSOA = PD.NRPESSOA
                                                  AND H1.NRORG = PD.NRORG
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Pagamentos*/
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = VH.NRORG
                          AND IT.NRVINCULOM = VH.NRVINCULOM
  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = IT.NRORG
                          AND CF.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
  /*Rubrica*/
  JOIN FPA_EVENTOM EM ON (EM.NRORG = IT.NRORG OR EM.NRORG = 0)
                     AND EM.NREVENTOM = IT.NREVENTOM
  JOIN FPA_EVENTOH EH ON EH.NRORG = EM.NRORG
                     AND EH.NREVENTOM = EM.NREVENTOM
                     AND EH.DTMESCOMPETENC  = (SELECT MAX(EHH.DTMESCOMPETENC) FROM FPA_EVENTOH EHH
                                                WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND EHH.NREVENTOM = EH.NREVENTOM
                                                  AND EHH.NRORG = EH.NRORG)
  /*Natureza da Rubrica*/
  JOIN NATUREZARUBRICA NR ON NR.NRNATURUBR = EH.NRNATURUBR
  /*Incidência Pensão*/
  JOIN FPA_INCIDEVENTO IE ON (IE.NRORG = IT.NRORG OR IE.NRORG = 0)
                         AND IE.NREVENTOM = IT.NREVENTOM
                         AND IE.NRTIPOINCIDE IN (76,132) /*DIRF - RTPA, INCIDE PENSAO FERIAS*/
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRPESSOA = :P_NRPESSOA
   AND SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
   AND EHN.DTINIMOVIMENT IS NULL AND EHS.DTINIMOVIMENT IS NULL
   AND CF.NRCALCULOFOLHA = :P_NRCALCULOFOLHA
   AND IT.NREVENTOM = :P_NREVENTOM
   AND IT.VREVENTOFOLHA > 0
   AND ((IT.IDEVENDEMONCALC = 'N' AND EH.IDEVENTODEMONST = 'N') OR (EH.IDEVENTODEMONST = 'S')) /*SE NÃO DEMONSTRATIVO NO CADASTRO E DEMONSTRATIVO NA FOLHA NÃO ENVIA*/
   AND (SELECT MAX(INC.CDESOCIAL)
          FROM FPA_INCIDEVENTO IE
          JOIN FPA_TIPOINCIDE TI ON TI.NRTIPOINCIDE = IE.NRTIPOINCIDE
                                AND INSTR(','||TI.DSNRTIPOMOVIMENT||',',','||CF.NRTIPOMOVIMENT||',') > 0
          JOIN INCIDENCIAIRRF INC ON INSTR(','||INC.DSNRTIPOINCIDE||',',','||TI.NRTIPOINCIDE||',') > 0
         WHERE (IE.NRORG = :P_NRORG OR IE.NRORG = 0)
           AND IE.NREVENTOM = IT.NREVENTOM
           AND (IE.NRTIPOINCIDE IN (SELECT NRTIPOINCIDE 
                                      FROM FPA_GRPITEM 
                                     WHERE NRGRPINCIDE = 47) OR TI.DSNRTIPOMOVIMENT IS NOT NULL)) IN (51, 52, 53, 54, 55) /*codIncIRRF - Pensao*/
 GROUP BY PD.NRCPFPESSOA, TO_CHAR(PD.DTNASCPESSOA, 'YYYY-MM-DD'), PD.NMPESSOA
UNION ALL
/*Pessoas com tranferência de saída na competência*/
SELECT PD.NRCPFPESSOA cpfBenef,
       TO_CHAR(PD.DTNASCPESSOA, 'YYYY-MM-DD') dtNasctoBenef,
       PD.NMPESSOA nmBenefic,
       SUM(ROUND(IT.VREVENTOFOLHA,2)) vlrPensao
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Movimentacao de saida*/
  JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 9
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHS ON EHS.NRORG = VH.NRORG
                                                                                                  AND EHS.NRVINCULOM = VH.NRVINCULOM
  /*Beneficiario*/
  JOIN FPA_DEPVINCULO PA ON PA.NRORG = VM.NRORG
                        AND PA.NRVINCULOM = VM.NRVINCULOM
                        AND PA.NRTIPODEPENDE = 3 /*Pensao Judicial*/
  JOIN GPE_PESSOAH PD ON PD.NRORG = PA.NRORG
                     AND PD.NRPESSOA = PA.NRPESSOA
                     AND PD.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH H1
                                                WHERE H1.NRPESSOA = PD.NRPESSOA
                                                  AND H1.NRORG = PD.NRORG
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Pagamentos*/
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = VH.NRORG
                          AND IT.NRVINCULOM = VH.NRVINCULOM
  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = IT.NRORG
                          AND CF.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
  /*Rubrica*/
  JOIN FPA_EVENTOM EM ON (EM.NRORG = IT.NRORG OR EM.NRORG = 0)
                     AND EM.NREVENTOM = IT.NREVENTOM
  JOIN FPA_EVENTOH EH ON EH.NRORG = EM.NRORG
                     AND EH.NREVENTOM = EM.NREVENTOM
                     AND EH.DTMESCOMPETENC  = (SELECT MAX(EHH.DTMESCOMPETENC) FROM FPA_EVENTOH EHH
                                                WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND EHH.NREVENTOM = EH.NREVENTOM
                                                  AND EHH.NRORG = EH.NRORG)
  /*Natureza da Rubrica*/
  JOIN NATUREZARUBRICA NR ON NR.NRNATURUBR = EH.NRNATURUBR
  /*Incidência Pensão*/
  JOIN FPA_INCIDEVENTO IE ON (IE.NRORG = IT.NRORG OR IE.NRORG = 0)
                         AND IE.NREVENTOM = IT.NREVENTOM
                         AND IE.NRTIPOINCIDE IN (76,132) /*DIRF - RTPA, INCIDE PENSAO FERIAS*/
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRPESSOA = :P_NRPESSOA
   AND SUBSTR(EHS.CDCNPJESTRUT,1,8) <> SUBSTR(EH.CDCNPJESTRUT,1,8)
   AND SUBSTR(EHS.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
   AND CF.NRCALCULOFOLHA = :P_NRCALCULOFOLHA
   AND IT.NREVENTOM = :P_NREVENTOM
   AND IT.VREVENTOFOLHA > 0
   AND ((IT.IDEVENDEMONCALC = 'N' AND EH.IDEVENTODEMONST = 'N') OR (EH.IDEVENTODEMONST = 'S')) /*SE NÃO DEMONSTRATIVO NO CADASTRO E DEMONSTRATIVO NA FOLHA NÃO ENVIA*/
   AND (SELECT MAX(INC.CDESOCIAL)
          FROM FPA_INCIDEVENTO IE
          JOIN FPA_TIPOINCIDE TI ON TI.NRTIPOINCIDE = IE.NRTIPOINCIDE
                                AND INSTR(','||TI.DSNRTIPOMOVIMENT||',',','||CF.NRTIPOMOVIMENT||',') > 0
          JOIN INCIDENCIAIRRF INC ON INSTR(','||INC.DSNRTIPOINCIDE||',',','||TI.NRTIPOINCIDE||',') > 0
         WHERE (IE.NRORG = :P_NRORG OR IE.NRORG = 0)
           AND IE.NREVENTOM = IT.NREVENTOM
           AND (IE.NRTIPOINCIDE IN (SELECT NRTIPOINCIDE 
                                      FROM FPA_GRPITEM 
                                     WHERE NRGRPINCIDE = 47) OR TI.DSNRTIPOMOVIMENT IS NOT NULL)) IN (51, 52, 53, 54, 55) /*codIncIRRF - Pensao*/
 GROUP BY PD.NRCPFPESSOA, TO_CHAR(PD.DTNASCPESSOA, 'YYYY-MM-DD'), PD.NMPESSOA
UNION ALL
/*Pessoas com tranferência de entrada na competência*/
SELECT PD.NRCPFPESSOA cpfBenef,
       TO_CHAR(PD.DTNASCPESSOA, 'YYYY-MM-DD') dtNasctoBenef,
       PD.NMPESSOA nmBenefic,
       SUM(ROUND(IT.VREVENTOFOLHA,2)) vlrPensao
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Movimentação de entrada*/
  JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT, MO.DTINIMOVIMENT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 8
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHN ON EHN.NRORG = VH.NRORG
                                                                                                   AND EHN.NRVINCULOM = VH.NRVINCULOM
                                                                                                   AND SUBSTR(EHN.CDCNPJESTRUT,1,8) = SUBSTR(EH.CDCNPJESTRUT,1,8)
  /*Movimentacao de saida*/
  JOIN (SELECT MO.NRORG, MO.NRESTRUTURAM, MO.NRVINCULOM, MO.DTFIMMOVIMENT, EM.NMESTRUTURAM, EH.CDCNPJESTRUT, MO.DTINIMOVIMENT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAM EM ON EM.NRORG = MO.NRORG
                                 AND EM.NRESTRUTURAM = MO.NRESTRUTURAM
               LEFT JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                 AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                 AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = EH.NRORG
                                                             AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRTIPOESTRUTURA = 1
                AND MO.NRTIPOTRANSFER = 1
                AND MO.NRTPMOVTRANSFM = 9
                AND SUBSTR(EH.CDCNPJESTRUT,1,8) <> SUBSTR(:P_NRINSCRICAOPARC,1,8)
                AND MO.DTINIMOVIMENT BETWEEN :P_DTMESCOMPETENC AND LAST_DAY(:P_DTMESCOMPETENC)) EHS ON EHS.NRORG = VH.NRORG
                                                                                                   AND EHS.NRVINCULOM = VH.NRVINCULOM
  /*Beneficiario*/
  JOIN FPA_DEPVINCULO PA ON PA.NRORG = VM.NRORG
                        AND PA.NRVINCULOM = VM.NRVINCULOM
                        AND PA.NRTIPODEPENDE = 3 /*Pensao Judicial*/
  JOIN GPE_PESSOAH PD ON PD.NRORG = PA.NRORG
                     AND PD.NRPESSOA = PA.NRPESSOA
                     AND PD.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH H1
                                                WHERE H1.NRPESSOA = PD.NRPESSOA
                                                  AND H1.NRORG = PD.NRORG
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Pagamentos*/
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = VH.NRORG
                          AND IT.NRVINCULOM = VH.NRVINCULOM
  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = IT.NRORG
                          AND CF.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
  /*Rubrica*/
  JOIN FPA_EVENTOM EM ON (EM.NRORG = IT.NRORG OR EM.NRORG = 0)
                     AND EM.NREVENTOM = IT.NREVENTOM
  JOIN FPA_EVENTOH EH ON EH.NRORG = EM.NRORG
                     AND EH.NREVENTOM = EM.NREVENTOM
                     AND EH.DTMESCOMPETENC  = (SELECT MAX(EHH.DTMESCOMPETENC) FROM FPA_EVENTOH EHH
                                                WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND EHH.NREVENTOM = EH.NREVENTOM
                                                  AND EHH.NRORG = EH.NRORG)
  /*Natureza da Rubrica*/
  JOIN NATUREZARUBRICA NR ON NR.NRNATURUBR = EH.NRNATURUBR
  /*Incidência Pensão*/
  JOIN FPA_INCIDEVENTO IE ON (IE.NRORG = IT.NRORG OR IE.NRORG = 0)
                         AND IE.NREVENTOM = IT.NREVENTOM
                         AND IE.NRTIPOINCIDE IN (76,132) /*DIRF - RTPA, INCIDE PENSAO FERIAS*/
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRPESSOA = :P_NRPESSOA
   AND SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
   AND CF.NRCALCULOFOLHA = :P_NRCALCULOFOLHA
   AND IT.NREVENTOM = :P_NREVENTOM
   AND IT.VREVENTOFOLHA > 0
   AND ((IT.IDEVENDEMONCALC = 'N' AND EH.IDEVENTODEMONST = 'N') OR (EH.IDEVENTODEMONST = 'S')) /*SE NÃO DEMONSTRATIVO NO CADASTRO E DEMONSTRATIVO NA FOLHA NÃO ENVIA*/
   AND (SELECT MAX(INC.CDESOCIAL)
          FROM FPA_INCIDEVENTO IE
          JOIN FPA_TIPOINCIDE TI ON TI.NRTIPOINCIDE = IE.NRTIPOINCIDE
                                AND INSTR(','||TI.DSNRTIPOMOVIMENT||',',','||CF.NRTIPOMOVIMENT||',') > 0
          JOIN INCIDENCIAIRRF INC ON INSTR(','||INC.DSNRTIPOINCIDE||',',','||TI.NRTIPOINCIDE||',') > 0
         WHERE (IE.NRORG = :P_NRORG OR IE.NRORG = 0)
           AND IE.NREVENTOM = IT.NREVENTOM
           AND (IE.NRTIPOINCIDE IN (SELECT NRTIPOINCIDE 
                                      FROM FPA_GRPITEM 
                                     WHERE NRGRPINCIDE = 47) OR TI.DSNRTIPOMOVIMENT IS NOT NULL)) IN (51, 52, 53, 54, 55) /*codIncIRRF - Pensao*/
 GROUP BY PD.NRCPFPESSOA, TO_CHAR(PD.DTNASCPESSOA, 'YYYY-MM-DD'), PD.NMPESSOA
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRPESSOA" => $nrpessoa,
            "P_NRINSCRICAOPARC" => $nrinscricaoparc,
            "P_NRCALCULOFOLHA" => $nrcalculofolha,
            "P_NREVENTOM" => $nreventom,
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    /**
     * @param $nrorg
     * @param $nrpessoa
     * @param $nrinscricaoparc
     * @param $dtocorrencia
     * @param $tppgto
     * @return array    Associative array
     */
    public function getDadosS1210detPgtoFer($nrorg, $nrpessoa, $nrinscricaoparc, $dtocorrencia) {
        $sql = <<<SQL
/*getDadosS1210detPgtoFer*/
SELECT CE.CDESOCIAL AS codCateg,
       CASE WHEN CE.CDESOCIAL IN ('101','102','103','104','105','106','111','301','302','303','305','306','307','308','309') THEN NVL(VH.CDMATRICULAESOCIAL, VM.NRVINCULOM) ELSE '' END AS matricula,
       TO_CHAR(GO.DTINIGOZOFERIAS, 'YYYY-MM-DD') AS dtIniGoz,
       GO.DTFIMGOZOFERIAS - GO.DTINIGOZOFERIAS + 1 AS qtDias,
       SUM(ROUND(IT.VREVENTOFOLHA,2)) vrLiq,
       /*detRubrFer getDadosS1210detRubrFer*/
       VM.NRORG, VM.NRPESSOA, CF.NRCALCULOFOLHA, :P_NRINSCRICAOPARC NRINSCRICAOPARC
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Remuneracao*/
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = VH.NRORG
                          AND IT.NRVINCULOM = VH.NRVINCULOM
                          AND IT.NREVENTOM = 3030
                          AND IT.DTOCORRENCIA = :P_DTOCORRENCIA
  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = IT.NRORG
                          AND CF.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
                          AND CF.NRTIPOMOVIMENT = 2
                          AND CF.NRTPMODALIDCAL = 1
  /*Categoria Trabalhador*/
  JOIN GPE_VINCULOEMPREG VE ON VE.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
  LEFT JOIN GPE_CATEGTRABESOC CE ON CE.NRCATEGESOC = VE.NRCATEGESOC
  /*Ferias*/
  JOIN FPA_FERIAS FE ON FE.NRORG = VM.NRORG
                    AND FE.NRVINCULOM = VM.NRVINCULOM
                    AND FE.IDCONTROLFERIAS IN ('GOZADO_INTEGRAL','GOZADO_PARCIAL')
  JOIN FPA_GOZOFERIAS GO ON GO.NRORG = FE.NRORG
                        AND GO.NRFERIAS = FE.NRFERIAS
                        /*Compara a quantidade de dias de gozo com a soma das referencias dos evento 210 e 220 para facilitar relacionar o gozo com o pagamento*/
                        /*AND (GO.DTFIMGOZOFERIAS - GO.DTINIGOZOFERIAS + 1) = (SELECT SUM(IC.VRREFFOLHA)
                                                                               FROM FPA_ITECALCFOLHA IC
                                                                              WHERE IC.NRORG = IT.NRORG
                                                                                AND IC.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
                                                                                AND IC.NRVINCULOM = IT.NRVINCULOM
                                                                                AND IC.NREVENTOM IN (210,220))
                        AND GO.DTINIGOZOFERIAS = (SELECT MIN(GH.DTINIGOZOFERIAS) FROM FPA_GOZOFERIAS GH
                                                   WHERE GH.NRORG = FE.NRORG
                                                     AND GH.NRFERIAS = FE.NRFERIAS
                                                     AND IT.DTOCORRENCIA BETWEEN GH.DTINIGOZOFERIAS-30 AND LAST_DAY(GH.DTINIGOZOFERIAS)+7)*/
                        /*Novo modo usando o relacionamento entre o período de gozo e seus lançamentos - 09/09/2020*/
                        AND (((GO.DTFIMGOZOFERIAS - GO.DTINIGOZOFERIAS + 1) = (SELECT SUM(IC.VRREFFOLHA)
                                                                               FROM FPA_ITECALCFOLHA IC
                                                                              WHERE IC.NRORG = IT.NRORG
                                                                                AND IC.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
                                                                                AND IC.NRVINCULOM = IT.NRVINCULOM
                                                                                AND IC.NREVENTOM IN (210,220))
                        AND GO.DTINIGOZOFERIAS = (SELECT MIN(GH.DTINIGOZOFERIAS) FROM FPA_GOZOFERIAS GH
                                                   WHERE GH.NRORG = FE.NRORG
                                                     AND GH.NRFERIAS = FE.NRFERIAS
                                                     AND IT.DTOCORRENCIA BETWEEN GH.DTINIGOZOFERIAS-30 AND LAST_DAY(GH.DTINIGOZOFERIAS)+7) AND IT.NRGOZOFERIAS IS NULL)
                          OR (GO.NRGOZOFERIAS = IT.NRGOZOFERIAS AND IT.NRGOZOFERIAS IS NOT NULL))
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRPESSOA = :P_NRPESSOA
   AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
   AND SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
 GROUP BY CE.CDESOCIAL,
       CASE WHEN CE.CDESOCIAL IN ('101','102','103','104','105','106','111','301','302','303','305','306','307','308','309') THEN NVL(VH.CDMATRICULAESOCIAL, VM.NRVINCULOM) ELSE '' END,
       TO_CHAR(GO.DTINIGOZOFERIAS, 'YYYY-MM-DD'),
       GO.DTFIMGOZOFERIAS - GO.DTINIGOZOFERIAS + 1,
       VM.NRORG, VM.NRPESSOA, CF.NRCALCULOFOLHA, :P_NRINSCRICAOPARC
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRPESSOA" => $nrpessoa,
            "P_NRINSCRICAOPARC" => $nrinscricaoparc,
            "P_DTOCORRENCIA" => $dtocorrencia,
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    /**
     * @param $nrorg
     * @param $nrpessoa
     * @param $nrinscricaoparc
     * @param $nrcalculofolha
     * @return array    Associative array
     */
    public function getDadosS1210detRubrFer($nrorg, $nrpessoa, $nrinscricaoparc, $nrcalculofolha) {
        $sql = <<<SQL
/*getDadosS1210detRubrFer*/
SELECT IT.NREVENTOM AS codRubr,
       CF.NRTIPOMOVIMENT AS ideTabrubr,
       ROUND(DECODE(IT.VRREFFOLHA, 0, '', IT.VRREFFOLHA),2) AS qtdRubr,
       ROUND(EH.VRPERCENTUALEVENTO,2) AS fatorRubr,
       ROUND(DECODE(IT.VRREFFOLHA, 0, '', (IT.VREVENTOFOLHA / IT.VRREFFOLHA)),2) AS vrUnit,
       ROUND(IT.VREVENTOFOLHA,2) AS vrRubr,
       /*penAlim getDadosS1210penAlim*/
       VM.NRORG, VM.NRPESSOA, CF.NRCALCULOFOLHA, :P_NRINSCRICAOPARC NRINSCRICAOPARC, IT.NREVENTOM
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Pagamentos*/
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = VH.NRORG
                          AND IT.NRVINCULOM = VH.NRVINCULOM
  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = IT.NRORG
                          AND CF.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
  /*Rubrica*/
  JOIN FPA_EVENTOM EM ON (EM.NRORG = IT.NRORG OR EM.NRORG = 0)
                     AND EM.NREVENTOM = IT.NREVENTOM
  JOIN FPA_EVENTOH EH ON EH.NRORG = EM.NRORG
                     AND EH.NREVENTOM = EM.NREVENTOM
                     AND EH.DTMESCOMPETENC  = (SELECT MAX(EHH.DTMESCOMPETENC) FROM FPA_EVENTOH EHH
                                                WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND EHH.NREVENTOM = EH.NREVENTOM
                                                  AND EHH.NRORG = EH.NRORG)
  /*Natureza da Rubrica*/
  JOIN NATUREZARUBRICA NR ON NR.NRNATURUBR = EH.NRNATURUBR
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRPESSOA = :P_NRPESSOA
   AND SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
   AND CF.NRCALCULOFOLHA = :P_NRCALCULOFOLHA
   AND IT.VREVENTOFOLHA > 0
   AND ((IT.IDEVENDEMONCALC = 'N' AND EH.IDEVENTODEMONST = 'N') OR (EH.IDEVENTODEMONST = 'S')) /*SE NÃO DEMONSTRATIVO NO CADASTRO E DEMONSTRATIVO NA FOLHA NÃO ENVIA*/
   AND (SELECT NVL(MAX(INC.CDESOCIAL),'00')
          FROM FPA_INCIDEVENTO IE
          JOIN FPA_TIPOINCIDE TI ON TI.NRTIPOINCIDE = IE.NRTIPOINCIDE
                                AND INSTR(','||TI.DSNRTIPOMOVIMENT||',',','||CF.NRTIPOMOVIMENT||',') > 0
          JOIN INCIDENCIAIRRF INC ON INSTR(','||INC.DSNRTIPOINCIDE||',',','||TI.NRTIPOINCIDE||',') > 0
         WHERE (IE.NRORG = :P_NRORG OR IE.NRORG = 0)
           AND IE.NREVENTOM = IT.NREVENTOM
           AND IE.NRTIPOINCIDE IN (SELECT NRTIPOINCIDE 
                                      FROM FPA_GRPITEM 
                                     WHERE NRGRPINCIDE = 47)) IN (00, 01, 09, 13, 33, 43, 46, 53, 63, 75, 93) /*codIncIRRF*/
 ORDER BY IT.NREVENTOM
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRPESSOA" => $nrpessoa,
            "P_NRINSCRICAOPARC" => $nrinscricaoparc,
            "P_NRCALCULOFOLHA" => $nrcalculofolha,
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    /**
     * @param $nrorg
     * @param $nrpessoa
     * @param $nrinscricaoparc
     * @param $dtocorrencia
     * @param $nrtpambiente
     * @return array    Associative array
     */
    public function getDadosS1210detPgtoAnt($nrorg, $nrpessoa, $nrinscricaoparc, $nrtabela, $dtocorrencia, $nrtpambiente, $inivalidadeamb) {
        $sql = <<<SQL
/*getDadosS1210detPgtoAnt*/
SELECT DISTINCT CE.CDESOCIAL AS codCateg,
       VM.NRORG, VM.NRPESSOA, :P_NRINSCRICAOPARC NRINSCRICAOPARC, :P_NRTABELA NRTABELA, :P_DTOCORRENCIA DTOCORRENCIA, :P_NRTPAMBIENTE NRTPAMBIENTE, :P_INIVALIDADEAMB INIVALIDADEAMB
       /*getDadosS1210infoPgtoAnt*/
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = VH.NRORG
                          AND IT.NRVINCULOM = VH.NRVINCULOM
                          AND IT.NREVENTOM IN (3030,3050)
                          AND IT.DTOCORRENCIA = :P_DTOCORRENCIA
  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = IT.NRORG
                          AND CF.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
                          AND CF.NRTIPOMOVIMENT = 1
                          AND CF.NRTPMODALIDCAL = 1
  /*Categoria Trabalhador*/
  JOIN GPE_VINCULOEMPREG VE ON VE.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
  LEFT JOIN GPE_CATEGTRABESOC CE ON CE.NRCATEGESOC = VE.NRCATEGESOC
 WHERE VM.NRORG = :P_NRORG
   AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
   AND ((VM.DTRESCISAOVINC < :P_INIVALIDADEAMB AND IT.NREVENTOM = 3050) OR (CF.DTOCORRENCIA < TRUNC(TO_DATE(:P_INIVALIDADEAMB),'MM') AND IT.NREVENTOM = 3030))
   AND VM.NRPESSOA = :P_NRPESSOA
   AND SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_INIVALIDADEAMB" => $inivalidadeamb,
            "P_NRPESSOA" => $nrpessoa,
            "P_NRINSCRICAOPARC" => $nrinscricaoparc,
            "P_NRTABELA" => $nrtabela,
            "P_DTOCORRENCIA" => $dtocorrencia,
            "P_NRTPAMBIENTE" => $nrtpambiente,
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    /**
     * @param $nrorg
     * @param $nrpessoa
     * @param $nrinscricaoparc
     * @param $dtocorrencia
     * @param $nrtpambiente
     * @return array    Associative array
     */
    public function getDadosS1210infoPgtoAnt($nrorg, $nrpessoa, $nrinscricaoparc, $codcateg, $nrtabela, $dtocorrencia, $nrtpambiente, $inivalidadeamb) {
        $sql = <<<SQL
/*getDadosS1210infoPgtoAnt*/
SELECT NVL(IRRF.CDESOCIAL,'00') AS tpBcIRRF,
       ROUND(SUM(IT.VREVENTOFOLHA * DECODE(IRRF.IDINCIDEVENTO,'-',-1,1)),2) AS vrBcIRRF
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Categoria Trabalhador*/
  JOIN GPE_VINCULOEMPREG VE ON VE.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
  JOIN GPE_CATEGTRABESOC CE ON CE.NRCATEGESOC = VE.NRCATEGESOC
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  JOIN FPA_ITECALCFOLHA IT ON IT.NRORG = VH.NRORG
                          AND IT.NRVINCULOM = VH.NRVINCULOM
  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = IT.NRORG
                          AND CF.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
                          AND CF.NRCALCULOFOLHA = (SELECT MAX(CA.NRCALCULOFOLHA)
                                                     FROM FPA_CALCULOFOLHA CA
                                                     JOIN FPA_ITECALCFOLHA IC ON IC.NRORG = CA.NRORG
                                                                             AND IC.NRCALCULOFOLHA = CA.NRCALCULOFOLHA
                                                    WHERE CA.NRORG = IT.NRORG
                                                      AND CA.NRCALCULOFOLHA = IT.NRCALCULOFOLHA
                                                      AND CA.NRTIPOMOVIMENT = 1
                                                      AND CA.NRTPMODALIDCAL = 1
                                                      AND IC.NRVINCULOM = IT.NRVINCULOM
                                                      --AND IC.NREVENTOM IN (3030,3050)
                                                      AND ((VM.DTRESCISAOVINC < :P_INIVALIDADEAMB AND IC.NREVENTOM = 3050) OR (CA.DTOCORRENCIA < TRUNC(TO_DATE(:P_INIVALIDADEAMB),'MM') AND IC.NREVENTOM = 3030))
                                                      AND IC.DTOCORRENCIA = :P_DTOCORRENCIA)
  /*Rubrica*/
  JOIN FPA_EVENTOM EM ON (EM.NRORG = IT.NRORG OR EM.NRORG = 0)
                     AND EM.NREVENTOM = IT.NREVENTOM
  /*IRRF NOVO*/
  LEFT JOIN (SELECT IE.NREVENTOM, TI.DSNRTIPOMOVIMENT, IE.IDINCIDEVENTO, MAX(INC.CDESOCIAL) AS CDESOCIAL
               FROM FPA_INCIDEVENTO IE
               JOIN FPA_TIPOINCIDE TI ON TI.NRTIPOINCIDE = IE.NRTIPOINCIDE
               JOIN INCIDENCIAIRRF INC ON INSTR(','||INC.DSNRTIPOINCIDE||',',','||TI.NRTIPOINCIDE||',') > 0
              WHERE (IE.NRORG = :P_NRORG OR IE.NRORG = 0)
                AND (IE.NRTIPOINCIDE IN (SELECT NRTIPOINCIDE 
                                      FROM FPA_GRPITEM 
                                     WHERE NRGRPINCIDE = 47) OR TI.DSNRTIPOMOVIMENT IS NOT NULL)
                AND INC.CDESOCIAL IS NOT NULL
              GROUP BY IE.NREVENTOM, TI.DSNRTIPOMOVIMENT, IE.IDINCIDEVENTO
             ) IRRF ON IRRF.NREVENTOM = EM.NREVENTOM
                   AND INSTR(','||IRRF.DSNRTIPOMOVIMENT||',',','||CF.NRTIPOMOVIMENT||',') > 0
 WHERE VM.NRORG = :P_NRORG
   AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
   AND VM.NRPESSOA = :P_NRPESSOA
   AND CE.CDESOCIAL = :P_CODCATEG
   AND SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(:P_NRINSCRICAOPARC,1,8)
 GROUP BY NVL(IRRF.CDESOCIAL,'00')
 HAVING ROUND(SUM(IT.VREVENTOFOLHA * DECODE(IRRF.IDINCIDEVENTO,'-',-1,1)),2) > 0
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_INIVALIDADEAMB" => $inivalidadeamb,
            "P_NRPESSOA" => $nrpessoa,
            "P_NRINSCRICAOPARC" => $nrinscricaoparc,
            "P_CODCATEG" => $codcateg,
            "P_DTOCORRENCIA" => $dtocorrencia
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
}