<?php
namespace HCM\Geral\Services;

use Doctrine\ORM\EntityManager;
use HCM\FPA\Services\ValorReferenciaService;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\Repositories;
use HCM\Util\DateUtil;
use HCM\Geral\Repository\AlteSalarioRepository;

class AlteSalarioService {

    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters, ValorReferenciaService $valorReferenciaService, VinculoServices $vinculoServices, AlteSalarioRepository $alteSalarioRepository) {
        $this->entityManager          = $entityManager;
        $this->hcmParameters          = $hcmParameters;
        $this->valorReferenciaService = $valorReferenciaService;
        $this->vinculoServices        = $vinculoServices;
        $this->alteSalarioRepository  = $alteSalarioRepository;
        
        $this->gpe_Altesalario = Repositories::GPE_ALTESALARIO;
    }

    public function beforeSave($nrorg, $nrvinculom, $dtaltesalario, $nrocorrencia) {
        try {
            $this->validaExisteDataOcorrenciaSalario($nrorg, $nrvinculom, $dtaltesalario, $nrocorrencia);
        } catch (\Exception $e) {
            throw $e;
        }
    }  
    
    // cria novo histórico para o vínculo caso não exista
    public function afterInsert($nrorg, $nrvinculom) {
        try {
            $this->vinculoServices->verificaHistoricoCompetencia($nrorg, $nrvinculom);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    // atualiza histórico vínculo
    public function afterSave($nrorg, $nrvinculom) {
        try {
            $this->atualizaAlteSalarioHistoricoVinculo($nrorg, $nrvinculom);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function atualizaAlteSalarioHistoricoVinculo($nrorg, $nrvinculom) {
        try {
            $gpevinculoh = $this->vinculoServices->retornaUltimoHistoricoCompetencia($nrorg, $nrvinculom);

            $gpevinculoh->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
            $gpevinculoh->setCdoperultatu($this->hcmParameters->getCdoperador());
            $gpevinculoh->setDtultatu(DateUtil::getDataAtual());

            $this->entityManager->persist($gpevinculoh);
            $this->entityManager->flush($gpevinculoh);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    

    public function valorMenorSalarioMinimo($vrsalario) {
        try {
            $salariominimo = $this->valorReferenciaService->getSalarioMinimo();
            if(is_object($salariominimo)){
                $vrsalminim = $salariominimo->getVrreferencia();
                if($vrsalario < $vrsalminim){
                    return true;
                }
            }
            return false;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Valida se já existe outro salario para o vínculo com a mesma data e mesma ocorrência
     *
     * @param $nrorg
     * @param $nrvinculom
     * @param $dtiniocupacao
     * @throws \Exception
     */
    public function validaExisteDataOcorrenciaSalario($nrorg, $nrvinculom, $dtaltesalario, $nrocorrencia) {
        try {
            $altesalarios = $this->entityManager->getRepository(Repositories::GPE_ALTESALARIO)
                ->findBy(array(
                    'nrorg' => $nrorg,
                    'nrvinculom' => $nrvinculom,
                    'dtaltesalario' => DateUtil::getDataDeString($dtaltesalario, DateUtil::FORMATO_BRASILEIRO, true),
                    'nrocorrencia' => $nrocorrencia
                ));
            if (!empty($altesalarios)) {
                throw new \Exception(Messages::HCM00000_GER_ALTESALARIO_DATA_OCOR_ALREADY_EXIST_ERROR, Messages::ERROR_MESSAGE_CODE);
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function nova($nrorg,$nrvinculom, $dtAlteracaoSalario, $nrOcorrencia, $nrTipoAlteracao, $vrSalario,
                         $idTipoSalario, $nrTipoModalideSalario, $observacao = null, $vrDiferencaReal = null, $vrPercentualReal = null,
                         $vrpercaltera = null)
    {
        $alteSalario = new $this->gpe_Altesalario;
        $alteSalario->setNrvinculom($nrvinculom);
        $alteSalario->setDtaltesalario($dtAlteracaoSalario);
        $alteSalario->setNrocorrencia($nrOcorrencia);
        $alteSalario->setNrtipoaltera($nrTipoAlteracao);
        $alteSalario->setVrpercaltera($vrpercaltera);
        $alteSalario->setVrsalario($vrSalario);
        $alteSalario->setNrorg($nrorg);
        $alteSalario->setIdtpsalario($idTipoSalario);
        $alteSalario->setNrtpmodalidsal($nrTipoModalideSalario);
        $alteSalario->setDsobservacao($observacao);

        $alteSalario->setVrdiferencareal($vrDiferencaReal);
        $alteSalario->setVrpercreal($vrPercentualReal);

        $alteSalario->setDtinclusao(DateUtil::getDataAtual());
        $alteSalario->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $alteSalario->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $alteSalario->setDtultatu(DateUtil::getDataAtual());
        $alteSalario->setCdoperultatu($this->hcmParameters->getCdoperador());
        $alteSalario->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        
        
        $alteSalario->setNraltesalario(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'GPE_ALTESALARIO', 1, 12, true));
        
        $this->entityManager->persist($alteSalario);
    }
    
    public function getSalarioPorCompetencia($nrorg, $nrvinculom, $dtcompetencia){
        return $this->alteSalarioRepository->getSalarioPorCompetencia($nrorg, $nrvinculom, $dtcompetencia);
    }

} 