<?php

namespace HCM\PTO\Controllers;

use \Zeedhi\Framework\DTO\Request\Filter;
use \Zeedhi\Framework\DTO\Response;
use \Zeedhi\Framework\DTO\Response\Message;
use \Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use HCM\PTO\Services\PeriodoApuracaoService;
use HCM\Util\HCMParameters;
use Zeedhi\Framework\DTO;


class PeriodoApuracaoController extends Crud {

    protected $dataSourceName = 'PeriodoApuracao';
    protected $dataSourceNameGetTipoPeriodoApuracao = 'getTipoPeriodoApuracao';
    protected $dataSourceSetTipoPeriodoApuracao     = 'ptoTipoPeriodoApuracao_setTipoPeriodoApuracao';
    protected $dataSourceGetPeriodo                 = 'getPeriodo';
    protected $dataSourceSetPeriodo                 = 'ptoPeriodoApuracao_setPeriodo';
    protected $periodoApuracao;
    protected $parameterBagColumns = array('NRORG', 'NRTIPOVINCULOM', 'NRTIPOPERIODOAPURACAO', 'IDATIVO');

    public function __construct(Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters, PeriodoApuracaoService $periodoApuracao) {
        $this->periodoApuracao = $periodoApuracao;
        $this->parameterBag = $parameterBag;
        $this->hcmParameters   = $hcmParameters;
        parent::__construct($dataSourceManager);
    }

    public function get($request, $response) {
        try {
            $periodoApuracao = $this->periodoApuracao->getPeriodoApuracao();
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet($this->dataSourceName, $periodoApuracao));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getTipoPeriodoApuracao($request, $response) {
        try{
            $this->parameterBagColumns = array('NRORG', 'NRTIPOVINCULOM');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceNameGetTipoPeriodoApuracao);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getPeriodo($request, $response) {
        try{
            $this->parameterBagColumns = array('NRORG', 'NRTIPOPERIODOAPURACAO');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetPeriodo);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getPeriodoApuracaoAtual($request, $response) {
        try {

            $filters = $request->getFilterCriteria()->getConditions();
            $parameters = array();
            foreach ($filters as $filter) {
                unset($filter['operator']);
                foreach ($filter as $key => $value) {
                    if ($key == 'columnName') {
                        $parameters[$value] = $filter['value'];
                        unset($filter['columnName']);
                    }
                }
            }

            list($periodoApuracao) = $this->periodoApuracao->getPeriodoApuracaoAtual($parameters, $filters);
            if (!is_null($periodoApuracao)) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getPeriodoApuracaoAtual', $periodoApuracao));
            } else {
                $response->addMessage(new Message("Periodo de apuração atual não encontrado."));
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function setTipoPeriodoApuracao (DTO\Request\DataSet $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceSetTipoPeriodoApuracao;
        try{
            foreach($request->getDataSet()->getRows() as $row) {

                if($row['__is_new'] === true){
                    $row['DTINCLUSAO'] = $row['DTATUAL'];
                    $row['CDOPERINCLUSAO'] = $row['CDOPERADOR_LOG'];
                    $row['NRORGINCLUSAO'] = $row['NRORGTRAB'];
                    $row['DTULTATU'] = $row['DTATUAL'];
                    $row['CDOPERULTATU'] = $row['CDOPERADOR_LOG'];
                    $row['NRORGULTATU'] = $row['NRORGTRAB'];
                    $row['NRTIPOPERIODOAPURACAO'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORGTRAB'], 'PTO_TIPOPERIODOAPURACAO', 1, 12, true);
                } else {
                    $row['DTULTATU'] = $row['DTATUAL'];
                    $row['CDOPERULTATU'] = $row['CDOPERADOR_LOG'];
                    $row['NRORGULTATU'] = $row['NRORGTRAB'];
                }
                
                $row['NRORG'] = $row['NRORGTRAB'];
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function setPeriodo (DTO\Request\DataSet $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceSetPeriodo;
        try{
            foreach($request->getDataSet()->getRows() as $row) {

                if($row['__is_new'] === true){
                    $row['DTINCLUSAO'] = $row['DTATUAL'];
                    $row['CDOPERINCLUSAO'] = $row['CDOPERADOR_LOG'];
                    $row['NRORGINCLUSAO'] = $row['NRORGTRAB'];
                    $row['DTULTATU'] = $row['DTATUAL'];
                    $row['CDOPERULTATU'] = $row['CDOPERADOR_LOG'];
                    $row['NRORGULTATU'] = $row['NRORGTRAB'];
                    $row['NRPERIODOAPURACAO'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORGPADRAO'], 'PTO_PERIODOAPURACAO', 1, 12, true);
                } else {
                    $row['DTULTATU'] = $row['DTATUAL'];
                    $row['CDOPERULTATU'] = $row['CDOPERADOR_LOG'];
                    $row['NRORGULTATU'] = $row['NRORGTRAB'];
                }
                
                $row['NRORG'] = $row['NRORGTRAB'];
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteTipoPeriodoApuracao (DTO\Request\Row $row, DTO\Response $response) {
        try{
            $dataSet = new DataSet($this->dataSourceSetTipoPeriodoApuracao, array($row->getRow()));
            $deletedRows = $this->dataSourceManager->delete($dataSet);

            $response->addDataSet(new DataSet($this->dataSourceSetTipoPeriodoApuracao, array('type' => 'success', $deletedRows)));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deletePeriodo (DTO\Request\Row $row, DTO\Response $response) {
        try{
            $dataSet = new DataSet($this->dataSourceSetPeriodo, array($row->getRow()));
            $deletedRows = $this->dataSourceManager->delete($dataSet);

            $response->addDataSet(new DataSet($this->dataSourceSetPeriodo, array('type' => 'success', $deletedRows)));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }

        $this->parameterBag->set('NRORG', $this->hcmParameters->getNrorgTrabalho());  
    

        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );


        return $newFilterCriteria;
    }

}