<?php

namespace HCM\TRE\Controllers;

use HCM\Geral\Services\UploadFileService;
use HCM\Geral\Controllers\EnviarMensagemController;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;
use HCM\Util\DateUtil;

class TreinamentoController extends Crud {

    protected $dataSourceName = '';
    protected $dataSourceName_Treinamento = 'tre_treinamento';
    protected $dataSourceName_Treinamento_get = 'getTreinamento';
    
    protected $dataSourceName_Participantes = 'tre_participantes_treinamento';
    protected $dataSourceName_Participantes_get = 'getParticipaTre';
    
    protected $dataSourceName_Documentos = 'tre_documentos_treinamento';
    protected $dataSourceName_Documentos_get = 'getDocumentosTre';
    
    protected $dataSourceName_Despesas = 'tre_despesas_treinamento';
    protected $dataSourceName_Despesas_get = 'getDespesasTre';
    
    protected $dataSourceName_Local = 'tre_local_treinamento';
    protected $dataSourceName_Local_get = 'getLocalTre';
    
    protected $dataSourceName_Material = 'tre_material_treinamento';
    protected $dataSourceName_Material_get = 'getMaterialTre';
    
    protected $dataSourceName_Avaliacao_get = 'getAvaliacaoTre';
    
    protected $dataSourceName_PerfilAcesso_get = 'tre_perfilacesso_get';
    
    protected $dataSourceName_Metodo_get = 'tre_metodo_get';
    
    protected $dataSourceName_TipoCusto_get = 'tre_tpcusto_get';
    
    protected $dataSourceName_Estrutura_Legal_get = 'tre_estrutura_legal_get';
    
    protected $dataSourceName_Estrutura_Gerencial_get = 'tre_estrutura_gerencial_get';
    
    protected $dataSourceName_Estrutura_Sindical_get = 'tre_estrutura_sindical_get';
    
    protected $dataSourceName_TipoDespesas_get = 'tre_despadmfatur_get';
    
    protected $dataSourceName_Produto_get = 'tre_produtos_get';
    
    protected $dataSourceName_Vinculom_get = 'tre_vinculom_get';
    
    protected $parameterBagColumns = array('P_NRORG', 'P_NRORG_PADRAO');
    
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters , \HCM\TRE\Services\TreinamentoService $treinamentoService, UploadFileService $uploadsFileService,EnviarMensagemController $enviarMensagemController){
        $this->parameterBag = $parameterBag;
        $this->hcmParameters = $hcmParameters;
        $this->treinamentoService = $treinamentoService;
        $this->uploadsFileService = $uploadsFileService;
        $this->enviarMensagemController = $enviarMensagemController;
        parent::__construct($dataSourceManager);
    }
    
    public function getTreinamento(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_Treinamento_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    public function setTreinamento_tre(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $this->dataSourceName = $this->dataSourceName_Treinamento;
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (array_key_exists('NRTREINAMENTO', $row)) {
                    if ($row['NRTREINAMENTO'] === '') {
                        $row['NRTREINAMENTO'] = \HCM\Util\NovoCodigo::geraCodigo( $row['NRORG'], 'GPE_TREINAMENTO', 1, 12, true);
                    }
                } else {
                    $row['NRTREINAMENTO'] = \HCM\Util\NovoCodigo::geraCodigo( $row['NRORG'], 'GPE_TREINAMENTO', 1, 12, true);
                }
                $row['NRPARCINSTRUTOR'] = (isset($row['NRPARCINSTRUTOR'])?$row['NRPARCINSTRUTOR']:null);
                $row['NRTPCUSTOTRE'] = ( isset($row['NRTPCUSTOTRE'])?$row['NRTPCUSTOTRE']:null);
                $row['NRCRITERIORESUL'] = ( isset($row['NRCRITERIORESUL'])?$row['NRCRITERIORESUL']:null);
                $row['NRPARCNEGAPROV'] = (isset($row['NRPARCNEGAPROV'])?$row['NRPARCNEGAPROV']:null);
                $row['NRPERFACESAPROV'] = (isset($row['NRPERFACESAPROV'])?$row['NRPERFACESAPROV']:null);
                $row['NRPERFACESEXEC'] = (isset($row['NRPERFACESEXEC'])?$row['NRPERFACESEXEC']:null);
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    public function deleteTreinamento_tre(DTO\Request\DataSet $request, DTO\Response $response){
        try{
            foreach ($request->getDataSet()->getRows() as &$row) {
                $val = $this->treinamentoService->validaDelete($row['NRORG'],$row['NRTREINAMENTO']);
                if(!is_string($val)){
                    $this->dataSourceName = $this->dataSourceName_Treinamento;
                    parent::delete($request, $response);
                }else{
                    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("Existem ".$val." relacionados a este treinamento, favor deleta-los antes de fazer a exclusão","E"));
                }
            }
        } catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }    
    }
    
    public function getParticipaTre(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_Participantes_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    public function setParticipantes_Treinamento(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $this->dataSourceName = $this->dataSourceName_Participantes;
            foreach ($request->getDataSet()->getRows() as &$row) {
                $row['CDTIPORESU'] = isset($row['CDTIPORESU'])? $row['CDTIPORESU'] : null;
                if (array_key_exists('NRPARTICIPATRE', $row)) {
                    if ($row['NRPARTICIPATRE'] === '') {
                        $row['NRPARTICIPATRE'] = \HCM\Util\NovoCodigo::geraCodigo( $row['NRORG'], 'GPE_PARTICIPATRE', 1, 12, true);
                    }
                } else {
                    $row['NRPARTICIPATRE'] = \HCM\Util\NovoCodigo::geraCodigo( $row['NRORG'], 'GPE_PARTICIPATRE', 1, 12, true);
                }
            if($this->treinamentoService->validaParticipantes($row['NRORG'],$row["NRTREINAMENTO"],$row["NRPARTICIPATRE"],$row["NRPARCNEGOCIO"]))
                parent::save($request, $response);
            else
                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("Participante já cadastrado para este treinamento","E"));
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    public function deleteParticipantes_Treinamento(DTO\Request\DataSet $request, DTO\Response $response){
        try{
                $this->dataSourceName = $this->dataSourceName_Participantes;
                parent::delete($request, $response);
            
        } catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }    
    }
    
    public function deletaTodosParticipantes(DTO\Request\DataSet $request, DTO\Response $response){
        try{
            $this->dataSourceName = $this->dataSourceName_Participantes;
            $dataset = $request->getDataSet()->getRows();
            $row = $dataset[0];
            $this->treinamentoService->deletaTodosParticipantes($row['NRORG'],$row['NRTREINAMENTO']);
        } catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getDocumentosTre(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_Documentos_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    public function setDocumentos_Treinamento(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            foreach ($request->getDataSet()->getRows() as &$row) {
                $upload = $this->treinamentoService->setDocumento($row);
                $response->addNotification(new \Zeedhi\Framework\DTO\Response\Notification('Arquivo salvo com sucesso','success',array($upload)));
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    public function deleteDocumentos_Treinamento(DTO\Request\DataSet $request, DTO\Response $response){
        try{
            foreach ($request->getDataSet()->getRows() as &$row) {
            $this->uploadsFileService->deleteUploadFile($row['DSREFARQUIVOTRE']);
            $this->dataSourceName = $this->dataSourceName_Documentos;
            parent::delete($request, $response);
            }
        } catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }    
    }
    
    public function getDespesasTre(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_Despesas_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    public function setDespesas_Treinamento(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $nrTreinamento = null;
            $this->dataSourceName = $this->dataSourceName_Despesas;
            
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (array_key_exists('NRDESPESATRE', $row)) {
                    if ($row['NRDESPESATRE'] === '') {
                        $row['NRDESPESATRE'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'GPE_DESPESATRE', 1, 12, true);
                    }
                } else {
                    $row['NRDESPESATRE'] = \HCM\Util\NovoCodigo::geraCodigo( $this->hcmParameters->getNrorgTrabalho(), 'GPE_DESPESATRE', 1, 12, true);
                }
                
                $nrTreinamento = $row['NRTREINAMENTO'];
            }
            
            parent::save($request, $response);

            $arrayValores = $this->treinamentoService->atualizarValorTreinamento($nrTreinamento);
            
            $response->addNotification(new Notification("TOTALDESPESASREAL:".$arrayValores['TOTALDESPESASREAL'], Notification::TYPE_SUCCESS));
            $response->addNotification(new Notification("TOTALDESPESASPLAN:".$arrayValores['TOTALDESPESASPLAN'], Notification::TYPE_SUCCESS));

        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    public function deleteDespesas_Treinamento(DTO\Request\DataSet $request, DTO\Response $response){
        try{
            $this->dataSourceName = $this->dataSourceName_Despesas;
            $nrTreinamento = $request->getDataSet()->getRows()[0]['NRTREINAMENTO'];

            parent::delete($request, $response);

            $arrayValores = $this->treinamentoService->atualizarValorTreinamento($nrTreinamento);
            
            $response->addNotification(new Notification("TOTALDESPESASREAL:".$arrayValores['TOTALDESPESASREAL'], Notification::TYPE_SUCCESS));
            $response->addNotification(new Notification("TOTALDESPESASPLAN:".$arrayValores['TOTALDESPESASPLAN'], Notification::TYPE_SUCCESS));

        } catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }    
    }
    
    public function getLocalTre(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_Local_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    public function setLocal_Treinamento(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $this->dataSourceName = $this->dataSourceName_Local;
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (array_key_exists('NRLOCALTREINAMENTO', $row)) {
                    if ($row['NRLOCALTREINAMENTO'] === '') {
                        $row['NRLOCALTREINAMENTO'] = \HCM\Util\NovoCodigo::geraCodigo( $row['NRORG'], 'GPE_LOCALTREINAMENTO', 1, 12, true);
                    }
                } else {
                    $row['NRLOCALTREINAMENTO'] = \HCM\Util\NovoCodigo::geraCodigo( $row['NRORG'], 'GPE_LOCALTREINAMENTO', 1, 12, true);
                }
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    public function deleteLocal_Treinamento(DTO\Request\DataSet $request, DTO\Response $response){
        try{
            $this->dataSourceName = $this->dataSourceName_Local;
            parent::delete($request, $response);
        } catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }    
    }
    
    public function getMaterialTre(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_Material_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    public function setMaterial_Treinamento(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $this->dataSourceName = $this->dataSourceName_Material;
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (array_key_exists('NRPRODUTOTRE', $row)) {
                    if ($row['NRPRODUTOTRE'] === '') {
                        $row['NRPRODUTOTRE'] = \HCM\Util\NovoCodigo::geraCodigo( $row['NRORG'], 'GPE_RESERVAPRODTRE', 1, 12, true);
                    }
                } else {
                    $row['NRPRODUTOTRE'] = \HCM\Util\NovoCodigo::geraCodigo( $row['NRORG'], 'GPE_RESERVAPRODTRE', 1, 12, true);
                }
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    public function deleteMaterial_Treinamento(DTO\Request\DataSet $request, DTO\Response $response){
        try{
            $this->dataSourceName = $this->dataSourceName_Material;
            parent::delete($request, $response);
        } catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }    
    }
    
    public function getAvaliacaoTre(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_Avaliacao_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }

    public function getMetodo_Treinamento(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_Metodo_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getTipoCusto_Treinamento(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_TipoCusto_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getEstrutura_Legal_tre(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_Estrutura_Legal_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }

    public function getEstrutura_Gerencial_tre(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_Estrutura_Gerencial_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }

    public function getEstrutura_Sindical_tre(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_Estrutura_Sindical_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }

    public function getTipoDespesa_tre(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_TipoDespesas_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }

    public function getPerfilAcesso_tre(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_PerfilAcesso_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }

    public function getProduto_tre(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_Produto_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getVinculom_tre(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_Vinculom_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function aprovaTreinamento(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            foreach ($request->getDataSet()->getRows() as &$row) {
                if($this->treinamentoService->validaPerfil($row['NRORG'],$row['NRPERFACESAPROV'],$this->hcmParameters->getCdoperador())){
                    if($this->treinamentoService->validaCustoTreinamento($row['NRORG'],$row['NRTREINAMENTO'],$row['VRCUSTOPLATREINAMENTO'])){
                        if((empty($this->treinamentoService->getParticipantes($row['NRORG'],$row['NRTREINAMENTO'])))&& $row['IDAPROV'] == "APROVADO" )
                            $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("Os participantes devem ser declarados antes do treinamento ser aprovado.", "E"));
                        else{
                        $replaceMnemonico = array(
                            "[NOME_TREINAMENTO]" => $row['NMTREINAMENTO'],
                            "[APROVACAO]" => strtolower($row['IDAPROV']),
                            "[OPERADOR]" => $this->treinamentoService->getOperador($row['NRORG'],$this->hcmParameters->getCdoperador())['NMOPERADOR'],
                            "[DATA_HORA_ATUAL]" => $this->hcmParameters->getDataAtual(false)
                        );
                        $content["DSTITULOMENSAGEM"]= strtr($row['DSTITULOMENSAGEM'], $replaceMnemonico);
                        $content["DSMENSAGEM"]= strtr($row['DSMENSAGEM'], $replaceMnemonico);
                        $this->enviarMensagemController->enviarEmail($content, $row['NRORG'], $this->hcmParameters->getDataAtual(),$this->treinamentoService->getParcNegocioByCdoperador($row['NRORG'],$row['CDOPERINCLUSAO'])['NRPARCNEGOCIO']);
                        if(isset($row['NRPARCINSTRUTOR']))
                            $this->enviarMensagemController->enviarEmail($content, $row['NRORG'], $this->hcmParameters->getDataAtual(), $row['NRPARCINSTRUTOR']);
                        $this->treinamentoService->aprovaTreinamento($row['NRORG'],$row['NRTREINAMENTO'],$row['IDAPROV'],isset($row['OBSAPROV'])?$row['OBSAPROV']:null,$this->treinamentoService->getParcNegocioByCdoperador($this->hcmParameters->getNrorgTrabalho(),$this->hcmParameters->getCdoperador())['NRPARCNEGOCIO'],$this->hcmParameters->getDataAtual());
                        $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("Treinamento ".strtolower($row['IDAPROV']), "M"));
                        }
                    }
                    else
                        $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("O custo planejado do treinamento não corresponde com o das despesas", "E"));
                }else 
                    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("O treinamento só pode ser aprovado por um operador pertencente ao perfil de aprovação", "E"));
                
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function executaTreinamento(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            foreach ($request->getDataSet()->getRows() as &$row) {
                if($this->treinamentoService->validaPerfil($row['NRORG'],$row['NRPERFACESEXEC'],$this->hcmParameters->getCdoperador())){
                    $vlcusto = $this->treinamentoService->validaCustoTreinamento($row['NRORG'],$row['NRTREINAMENTO'],$row['VRCUSTOPLATREINAMENTO'],$row['VRCUSTOREALTREINAMENTO'],true);
                    if($vlcusto['REAL'] && $vlcusto['PLANEJADO']){
                        $replaceMnemonico = array(
                            "[NOME_TREINAMENTO]" => $row['NMTREINAMENTO'],
                            "[DATA_HORA_ATUAL]" => $this->hcmParameters->getDataAtual(false)
                        );
                        $content["DSTITULOMENSAGEM"]= strtr($row['DSTITULOMENSAGEM'], $replaceMnemonico);
                        $content["DSMENSAGEM"]= strtr($row['DSMENSAGEM'], $replaceMnemonico);
                        $this->enviarMensagemController->enviarEmail($content, $row['NRORG'], $this->hcmParameters->getDataAtual(), $this->treinamentoService->getParcNegocioByCdoperador($row['NRORG'],$row['CDOPERINCLUSAO'])['NRPARCNEGOCIO']);
                        if(isset($row['NRPARCINSTRUTOR']))
                            $this->enviarMensagemController->enviarEmail($content, $row['NRORG'], $this->hcmParameters->getDataAtual(), $row['NRPARCINSTRUTOR']);
                        $this->treinamentoService->executaTreinamento($row['NRORG'],$row['NRTREINAMENTO'],$this->hcmParameters->getDataAtual());
                    }
                    else
                        if(!$vlcusto['REAL'] && !$vlcusto['PLANEJADO'])
                            $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("O custo planejado e real do treinamento não corresponde com o das despesas", "E"));
                        elseif (!$vlcusto['PLANEJADO']) 
                            $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("O custo planejado do treinamento não corresponde com o das despesas", "E"));
                        else 
                            $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("O custo real do treinamento não corresponde com o das despesas", "E"));

                }else {
                    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("O treinamento só pode ser iniciado por um operador pertencente ao perfil de execução", "E"));
                }
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function enviaConvites(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            foreach ($request->getDataSet()->getRows() as &$row) {
                $participantes_list = $this->treinamentoService->getParticipantes($row['NRORG'],$row['NRTREINAMENTO']);
                if(!empty($participantes_list)){
                    $curso = $this->treinamentoService->getCurso($row['NRORG'],$row['NRCURSO']);
                    foreach ($participantes_list as &$participante){
                        if($row['NRPARCINSTRUTOR'] != null){
                            $replaceMnemonico = array(
                                "[CODIGO_PARTICIPANTE]"=>$participante['NRPARTICIPATRE'],
                                "[NOME_PARTICIPANTE]"=>$this->treinamentoService->getParcNegocio($row['NRORG'],$participante['NRPARCNEGOCIO'])['NMPRINCIPALPARC'],
                                "[CODIGO_TREINAMENTO]"=>$row['NRTREINAMENTO'],
                                "[NOME_TREINAMENTO]"=>$row['NMTREINAMENTO'],
                                "[CODIGO_CURSO]"=>$row['NRCURSO'],
                                "[NOME_CURSO]"=>$curso['NMCURSO'],
                                "[DATA_INICIO_TREINAMENTO]"=>explode(" ",$row['DTINIPLANEJADOTRE'])[0],
                                "[DATA_FIM_TREINAMENTO]"=>explode(" ",$row['DTFIMPLANEJADOTRE'])[0],
                                "[CARGA_HOR_CURSO]"=>$curso['QTCARGAHORARIA'],
                                "[NOME_INSTRUTOR]"=>$this->treinamentoService->getParcNegocio($row['NRORG'],$row['NRPARCINSTRUTOR'])['NMPRINCIPALPARC'],
                                "[LISTA_LOCAIS_TREINAMENTO]"=>$this->treinamentoService->listaLocais($row['NRORG'],$row['NRTREINAMENTO'])
                            );
                        } else {
                            $replaceMnemonico = array(
                                "[CODIGO_PARTICIPANTE]"=>$participante['NRPARTICIPATRE'],
                                "[NOME_PARTICIPANTE]"=>$this->treinamentoService->getParcNegocio($row['NRORG'],$participante['NRPARCNEGOCIO'])['NMPRINCIPALPARC'],
                                "[CODIGO_TREINAMENTO]"=>$row['NRTREINAMENTO'],
                                "[NOME_TREINAMENTO]"=>$row['NMTREINAMENTO'],
                                "[CODIGO_CURSO]"=>$row['NRCURSO'],
                                "[NOME_CURSO]"=>$curso['NMCURSO'],
                                "[DATA_INICIO_TREINAMENTO]"=>explode(" ",$row['DTINIPLANEJADOTRE'])[0],
                                "[DATA_FIM_TREINAMENTO]"=>explode(" ",$row['DTFIMPLANEJADOTRE'])[0],
                                "[CARGA_HOR_CURSO]"=>$curso['QTCARGAHORARIA'],
                                "[LISTA_LOCAIS_TREINAMENTO]"=>$this->treinamentoService->listaLocais($row['NRORG'],$row['NRTREINAMENTO'])
                            );
                        }
                        $content["DSTITULOMENSAGEM"]= strtr($row['DSTITULOMENSAGEM'], $replaceMnemonico);
                        $content["DSMENSAGEM"]= strtr($row['DSMENSAGEM'], $replaceMnemonico);
                        $this->enviarMensagemController->enviarEmail($content, $row['NRORG'], $this->hcmParameters->getDataAtual(), $participante['NRPARCNEGOCIO']);
                    }
                    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("Convites Enviados", "M"));
                }
                else
                    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("Nenhum participante encontrado", "E"));

                
            }
            
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function cancelaTreinamento(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            foreach ($request->getDataSet()->getRows() as &$row) {
                if(($this->treinamentoService->validaPerfil($row['NRORG'],$row['NRPERFACESAPROV'],$this->hcmParameters->getCdoperador()))|| ($row['CDOPERINCLUSAO'] == $this->hcmParameters->getCdoperador())){
                    $parcnegOpera = $this->treinamentoService->getParcNegocioByCdoperador($this->hcmParameters->getNrorgTrabalho(),$this->hcmParameters->getCdoperador());
                    $replaceMnemonico = array(
                        "[NOME_TREINAMENTO]" => $row['NMTREINAMENTO'],
                        "[DATA_HORA_ATUAL]" => $this->hcmParameters->getDataAtual(false)
                    );
                    $content["DSTITULOMENSAGEM"]= strtr($row['DSTITULOMENSAGEM'], $replaceMnemonico);
                    $content["DSMENSAGEM"]= strtr($row['DSMENSAGEM'], $replaceMnemonico);
                    if($row['CDOPERINCLUSAO'] !== $this->hcmParameters->getCdoperador())
                        $this->enviarMensagemController->enviarEmail($content, $row['NRORG'], $this->hcmParameters->getDataAtual(), $this->treinamentoService->getParcNegocioByCdoperador($row['NRORG'],$row['CDOPERINCLUSAO'])['NRPARCNEGOCIO']);
                    if(isset($row['NRPARCNEGAPROV']) && $row['NRPARCNEGAPROV'] != $parcnegOpera['NRPARCNEGOCIO'])
                        $this->enviarMensagemController->enviarEmail($content, $row['NRORG'], $this->hcmParameters->getDataAtual(), $row['NRPARCINSTRUTOR']);
                    if(isset($row['NRPARCINSTRUTOR']))
                        $this->enviarMensagemController->enviarEmail($content, $row['NRORG'], $this->hcmParameters->getDataAtual(), $parcnegOpera['NRPARCNEGOCIO']);
                    $this->treinamentoService->cancelaTreinamento($row['NRORG'],$row['NRTREINAMENTO'],$this->hcmParameters->getDataAtual());
                    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("Treinamento cancelado", "M"));
                }else {
                    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("O treinamento só pode ser cancelado por um operador pertencente ao perfil de aprovação ou o responsavel pela sua inclusão", "E"));
                }
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function atestaEficacia(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            foreach ($request->getDataSet()->getRows() as &$row) {
                if($this->treinamentoService->validaPerfil($row['NRORG'],$row['NRPERFACESAPROV'],$this->hcmParameters->getCdoperador())){
                    $this->treinamentoService->atestaEficacia($row['NRORG'],$row['NRTREINAMENTO'],$row['IDEFIC'],$row['OBSEFIC']);
                }else 
                    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("A eficacia do treinamento só pode ser atestada por um operador pertencente ao perfil de execução", "E"));
                
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function concluiTreinamento(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            foreach ($request->getDataSet()->getRows() as &$row) {
                if($this->treinamentoService->validaPerfil($row['NRORG'],$row['NRPERFACESEXEC'],$this->hcmParameters->getCdoperador())){
                    $vlconc = $this->treinamentoService->validaConclusao($row['NRORG'],$row['NRTREINAMENTO']);
                    if($vlconc[0]){
                        $vlcusto = $this->treinamentoService->validaCustoTreinamento($row['NRORG'],$row['NRTREINAMENTO'],$row['VRCUSTOPLATREINAMENTO'],$row['VRCUSTOREALTREINAMENTO'],true);
                        if($vlcusto['REAL'] && $vlcusto['PLANEJADO']){
                        $this->treinamentoService->concluiTreinamento($row['NRORG'],$row['NRTREINAMENTO'],$this->hcmParameters->getDataAtual());
                            $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("Treinamento concluido", "M"));
                        }
                        else
                            if(!$vlcusto['REAL'] && !$vlcusto['PLANEJADO'])
                                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("O custo planejado e real do treinamento não corresponde com o das despesas", "E"));
                            elseif (!$vlcusto['PLANEJADO']) 
                                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("O custo planejado do treinamento não corresponde com o das despesas", "E"));
                            else 
                                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("O custo real do treinamento não corresponde com o das despesas", "E"));
                    }
                    else{
                        if(empty($vlconc[1]))
                                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("Nenhum participante encontrado", "E"));
                        else
                                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("É necessário que todas as notas e percentuais de frequência sejam lançados antes do treinamento ser concluído.", "E"));
                    }
                }else {
                    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("O treinamento só pode ser concluido por um operador pertencente ao perfil de execução", "E"));
                }
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function cadastroAutomatico(DTO\Request\DataSet $request, DTO\Response $response){
        foreach ($request->getDataSet()->getRows() as &$row) {
    
            $row['NRESTRUTSIND'] = isset($row['NRESTRUTSIND'])?$row['NRESTRUTSIND']:array();
            $row['NRESTRUTLEGAL'] = isset($row['NRESTRUTLEGAL'])?$row['NRESTRUTLEGAL']:array();
            $row['NRESTRUTGEREN'] = isset($row['NRESTRUTGEREN'])?$row['NRESTRUTGEREN']:array();
            $row['NRVINCULOM_LIST'] = isset($row['NRVINCULOM_LIST'])?$row['NRVINCULOM_LIST']:array();
            
            $return = $this->treinamentoService->CadastroAutomatico($row['NRORG'],$row['NRTREINAMENTO'],$row['NRCURSO'],$row['IDCURSOREC'],$row['IDCURSODES'],$row['IDVALIDA'],$row['NRESTRUTSIND'],$row['NRESTRUTLEGAL'],$row['NRESTRUTGEREN'],$row['NRVINCULOM_LIST']);
            if($return == 0)
                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("Nenhum novo registro encontrado dentro destes parametros","M"));
            else
                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message($return." registros cadastrados com sucesso","M"));
        }
    }
    
    public function calculaResultado(DTO\Request\DataSet $request, DTO\Response $response){
        foreach ($request->getDataSet()->getRows() as &$row) {
            $this->treinamentoService->calculaResultado($row['NRORG'],$row['NRTREINAMENTO'],$row['NRCRITERIORESUL']);
        }
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
}
