<?php

namespace HCM\Util;

use HCM\FPA\Calculos\Geral\MemoriaCalculo;

class TkEvaluator
{
    private $_env = array();
    public $objects = array();

    public function __construct() {
        $this->addDefaultFunctions();
    }

    function setVar($name, $value)
    {
        $this->_env[$name] = new TkCode((string)$value);
    }

    function setFunction($name, $params, $code)
    {
        $this->_env[$name] = new TkFunction($params, new TkCode($code));
    }

    function setObjectVar($name, $object, $property)
    {
        $this->_env[$name] = new TkEvaluatorObject($name, $property);
        $this->objects[$name] =& $object;
    }

    function setObjectFunction($name, $object, $method, $params = array())
    {
        $this->_env[$name] = new TkEvaluatorObjectFunction($name, $method, $params);
        $this->objects[$name] =& $object;
    }

    function evaluate($code, $debug = false)
    {
        $ruleValue = array();
        $self = $this;
        $initial_code = '';
        $returnMemoria = '';
        foreach ($this->_env as $name => $value) {
            $initial_code .= "\$$name ";
            if ($value instanceof TkEvaluatorObject) {
                $initial_code .= "=& ";
            } else {
                $initial_code .= "= ";
            }

            $initial_code .= "{$value->getAsPHP(array_keys($this->_env), $debug)};";
        }
        
        eval($initial_code);

        $codes = explode(';', $code);
        
        foreach ($codes as $code) {
            $php_code = "";
            $code = new TkCode($code);
            $php_code .= "\$return = ";
            $php_code .= $code->getAsPHP(array_keys($this->_env));
            
            
            try {
                eval($php_code);
            } catch (ParseError $t) {
                return null;
            }
            
            if ($return === ABORT) {
                return;
            }
            preg_match_all('/\$(\w+\()\'*\w*\'*\)/',$php_code,$matches);
            foreach ($matches[0] as $indice){
                $indice_code = "\$returnMemory = ".$indice.';';
                eval($indice_code);
                array_push($ruleValue,$returnMemory);
            }
            $valuesRules = array_combine($matches[0],$ruleValue);
            MemoriaCalculo::getInstance()->setValoresRegra($valuesRules);
        }
        return $return;
    }

    public function testEvaluate($expression)
    {
        return (boolean)$expression === false ? ABORT : $expression;
    }

    protected function addDefaultFunctions()
    {
        $this->setObjectFunction('test', $this, 'testEvaluate', array('expression'));
    }
}

class TkEvaluatorObject
{

    private $_object;

    public function __construct($object, $property)
    {
        $this->_object = $object;
        $this->_property = $property;
    }
    
    public function getAsPHP()
    {
        return '$this->objects["'.$this->_object.'"]->'.$this->_property;
    }


}

class TkEvaluatorObjectFunction
{

    private $_name;
    private $_method;

    public function __construct($name, $method, $params)
    {
        $this->_name = $name;
        $this->_method = $method;
        $this->_params = $params;
    }

    public function getAsPHP($env = null, $debug = false)
    {
        $env = null;
        $params = implode(',', array_map(function($item)
                                 {
                                     return '$'.$item;
                                 }, $this->_params));
        
        if($this->_name == 'SE'){
            $return = 'function('.$params.' = null) use ($self) {';
        }else{
            $return = 'function('.$params.') use ($self) {';
        }
        
        if ($debug) {
            $return .= '$debug = \''.$this->_name.'<br />\';';
            $return .= '$debug .= "Entrada: ".var_export(func_get_args(), true);';
        }

        $return .= '$result = $self->objects["'.$this->_name.'"]->'.$this->_method.'('.$params.');';
        if ($debug) {
            $return .= '$debug .= \'<br />Retorno: \'.$result;';
        }

        $return .= 'return $result;';
        $return .= '}';
        return $return;
    }

}