<?php
/**
 * Salario Familia.
 *
 * @package Logic
 *
 * @author  alessandrobartels
 */
class SalarioFamilia {


    /**
     * Calcula o Salario Familia.
     *
     * @param integer               $incidencia      Numero da Incidencia.
     * @param integer               $evento          Numero do evento.
     * @param TkDateTime            $mes_competencia Mes de competencia.
     * @param FpaitecalcfolhaEntity $item_de_calculo Item de calculo.
     * @param FpaassoceventoEntity  $assoc_eventos   Associacao de evento.
     * @param FpaeventomEntity      $eventom         Evento.
     * @param GpevinculomEntity     $vinculo         Vinculo.
     * @param string                $dias_normais    Dias Normais.
     * @param string                $salario_base         Salario.
     *
     * @return void
     *
     * @author alessandrobartels -
     *         alessandrobartels - 27/06/2011 - Implementacao do NRORG no metodo retornaEvento
     */
    public static function calcula(
        $incidencia, $evento, TkDateTime $mes_competencia, FpaitecalcfolhaEntity $item_de_calculo,
        FpaassoceventoEntity $assoc_eventos, FpaeventomEntity $eventom, GpevinculomEntity $vinculo,
        $dias_normais,$salario_base
    ){
        $num_dependentes = $vinculo->historico->getNrdependsfam();
        $base = $item_de_calculo->calculaIncidencias($incidencia, $mes_competencia, $eventom);

        $referencia = 0;
//        //BORBA 30/10/2013 - Cota máxima obtida através do salario base
//        $cota = FpafaixatabelaEntity::retornaValorProcessado(
//            $salario_base, FpatabelafolhaEntity::TAB_SALARIO_FAMILIA,
//            $mes_competencia, $referencia
//        );
        //BORBA 04/11/2014 - Conforme solicitação 154343. Verifica se o base dá direito ao Salário família; = 0 perde o direito
        $verificadireito = FpafaixatabelaEntity::retornaValorProcessado(
            $salario_base, FpatabelafolhaEntity::TAB_SALARIO_FAMILIA,$mes_competencia, $referencia
        );

        //BORBA 30/10/2013 - Cota máxima obtida através da incidencia sobre o salario família
        $cota = FpafaixatabelaEntity::retornaValorProcessado(
            $base, FpatabelafolhaEntity::TAB_SALARIO_FAMILIA, $mes_competencia, $referencia
        );

//        //BORBA 30/10/2013 - Deve ser enviada a cota menor, se cota for maior que cota1 ela é sobreposta por cota1
//        if ($cota>$cota1){
//            $cota=$cota1;
//        }

        //BORBA 04/11/2014 - Conforme solicitação 154343. Verifica se o base dá direito ao Salário família; = 0 perde o direito
        if ($verificadireito==0){
            $cota=0.0;
        } else {
            //Marcelo Solicitação 0000156439 06/02/2014 O direito ao salario familia deve ser verificado pelo salario base porem, deve-se considerar
            //a menor cota possível. Aquela oriunda do salário do vínculo ou aquela referente à remuneração variável do mes
            if ($cota>$verificadireito){
                $cota=$verificadireito;
            }
        }		
		

        $sal_familia = $cota * $num_dependentes;
//        $sal_familia = ($cota/30*$dias_normais) * $num_dependentes;
        $nrevento =  $assoc_eventos->retornaEvento($evento, $vinculo->getNrorg());
        $evento_sal_familia = $eventom->retornaEvento($nrevento);

        /*$item_de_calculo->geraEvento(
            $evento_sal_familia, $mes_competencia, $sal_familia, $num_dependentes, 1
        );*/

        /* alessandrobartels 30/08/2011 - Testa tipo de referencia para gerar o percentual ou numero de dependentes */
        if ($evento_sal_familia->historico->getIdunidrefereven() === FpaeventohEntity::IDUNIDREFEREVEN_COTA) {
            $referencia = $num_dependentes;
        }

        $item_de_calculo->geraEvento(
            $evento_sal_familia, null, $sal_familia, $referencia, 1
        );
    }


}